/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ZvAgF9N8);
  numBytes += sLine_init(&sLine_we3l5QFX);
  numBytes += sLine_init(&sLine_F87eOyfa);
  numBytes += sLine_init(&sLine_HyU76aGI);
  numBytes += sLine_init(&sLine_8C7CWo4U);
  numBytes += sBiquad_init(&sBiquad_s_TJuaseFU);
  numBytes += sLine_init(&sLine_wnDeZ73n);
  numBytes += sLine_init(&sLine_5IFJj3U6);
  numBytes += sLine_init(&sLine_AsHt4w2x);
  numBytes += sLine_init(&sLine_0ef5wMEw);
  numBytes += sBiquad_init(&sBiquad_s_IWJxlgrL);
  numBytes += sLine_init(&sLine_nJK8s5ew);
  numBytes += sLine_init(&sLine_PUlM3jbL);
  numBytes += sLine_init(&sLine_beccf2W7);
  numBytes += sLine_init(&sLine_j1dsbIxQ);
  numBytes += sLine_init(&sLine_qugRxuIp);
  numBytes += sBiquad_init(&sBiquad_s_3kVuIKOD);
  numBytes += sLine_init(&sLine_5C7ihpwN);
  numBytes += sLine_init(&sLine_5Lu03wVh);
  numBytes += sLine_init(&sLine_1465mirn);
  numBytes += sLine_init(&sLine_BjT1Dq6i);
  numBytes += sLine_init(&sLine_A9mgmbG8);
  numBytes += sBiquad_init(&sBiquad_s_hB9JTZ7E);
  numBytes += sLine_init(&sLine_0dLIN6A7);
  numBytes += sLine_init(&sLine_PHeP7A0y);
  numBytes += sLine_init(&sLine_hafV42BE);
  numBytes += sLine_init(&sLine_0SpwpJPL);
  numBytes += sBiquad_init(&sBiquad_s_O3idtb1u);
  numBytes += sLine_init(&sLine_SYcW4oJO);
  numBytes += sLine_init(&sLine_ODGBWXBW);
  numBytes += sLine_init(&sLine_BtsKVKf3);
  numBytes += sLine_init(&sLine_r6h6C8In);
  numBytes += sLine_init(&sLine_NP6lxrdh);
  numBytes += sBiquad_init(&sBiquad_s_D6W79cbI);
  numBytes += sLine_init(&sLine_IUL07AzI);
  numBytes += sTabread_init(&sTabread_BVxw12tT, &hTable_bfMHjUIg, true);
  numBytes += sLine_init(&sLine_CuuPYCt1);
  numBytes += sLine_init(&sLine_mSzajeyt);
  numBytes += sTabread_init(&sTabread_alXsi6o1, &hTable_TKQiRNT0, true);
  numBytes += sLine_init(&sLine_qpYvlRBI);
  numBytes += sRPole_init(&sRPole_FRt1Frue);
  numBytes += sDel1_init(&sDel1_RjucjkbO);
  numBytes += sTabwrite_init(&sTabwrite_2GitFjeT, &hTable_bfMHjUIg);
  numBytes += sRPole_init(&sRPole_oZimjQoc);
  numBytes += sDel1_init(&sDel1_rDdRTDNV);
  numBytes += sTabwrite_init(&sTabwrite_0UsS9AuZ, &hTable_TKQiRNT0);
  numBytes += sLine_init(&sLine_bK64IFnG);
  numBytes += sLine_init(&sLine_QFkLIRGx);
  numBytes += sRPole_init(&sRPole_AtekGD6f);
  numBytes += sEnv_init(&sEnv_nANzx3UD, 1024, 512);
  numBytes += sRPole_init(&sRPole_EIGKSCn1);
  numBytes += sLine_init(&sLine_s8X0LSXF);
  numBytes += sLine_init(&sLine_AFnoiCaE);
  numBytes += sRPole_init(&sRPole_yFJPUwT4);
  numBytes += sEnv_init(&sEnv_rZJppz6b, 1024, 512);
  numBytes += sRPole_init(&sRPole_7nUqDMUz);
  numBytes += sLine_init(&sLine_Of0RFGzc);
  numBytes += sTabread_init(&sTabread_8SeePa5K, &hTable_zi1xCbSs, true);
  numBytes += sLine_init(&sLine_8YO848gA);
  numBytes += sLine_init(&sLine_ErK33IlO);
  numBytes += sTabread_init(&sTabread_SLrxXmwY, &hTable_pY6tUaMi, true);
  numBytes += sLine_init(&sLine_VtbyeAnR);
  numBytes += sRPole_init(&sRPole_LfAur212);
  numBytes += sDel1_init(&sDel1_y3A77yE9);
  numBytes += sTabwrite_init(&sTabwrite_bh0O2vyD, &hTable_zi1xCbSs);
  numBytes += sRPole_init(&sRPole_Ou7FFuir);
  numBytes += sDel1_init(&sDel1_AfZUj88k);
  numBytes += sTabwrite_init(&sTabwrite_9NIpHuaG, &hTable_pY6tUaMi);
  numBytes += sLine_init(&sLine_WvPylBzD);
  numBytes += sLine_init(&sLine_clWbRxZx);
  numBytes += sRPole_init(&sRPole_fAFEWxuE);
  numBytes += sEnv_init(&sEnv_9eZh7Kzo, 1024, 512);
  numBytes += sRPole_init(&sRPole_56uQnv0G);
  numBytes += sLine_init(&sLine_3QUy4KzU);
  numBytes += sLine_init(&sLine_Qmm3hGRE);
  numBytes += sRPole_init(&sRPole_fP1MeIRq);
  numBytes += sEnv_init(&sEnv_emHV5Ijb, 1024, 512);
  numBytes += sRPole_init(&sRPole_GfmHoa6D);
  numBytes += sLine_init(&sLine_YmVBXEZM);
  numBytes += sTabread_init(&sTabread_CtZzHWZD, &hTable_2SDigbFI, true);
  numBytes += sLine_init(&sLine_5CHQrvtL);
  numBytes += sLine_init(&sLine_v6r3QXog);
  numBytes += sTabread_init(&sTabread_SyMbVr0O, &hTable_Y4T68Ejp, true);
  numBytes += sLine_init(&sLine_IFhTHKi1);
  numBytes += sRPole_init(&sRPole_1ZBhGghe);
  numBytes += sDel1_init(&sDel1_OZEYnsMi);
  numBytes += sTabwrite_init(&sTabwrite_LBpS7k3D, &hTable_2SDigbFI);
  numBytes += sRPole_init(&sRPole_2NL9iDAs);
  numBytes += sDel1_init(&sDel1_hZuhN6j4);
  numBytes += sTabwrite_init(&sTabwrite_a02eutDN, &hTable_Y4T68Ejp);
  numBytes += sLine_init(&sLine_cMGsPYMu);
  numBytes += sLine_init(&sLine_aB3XDVck);
  numBytes += sRPole_init(&sRPole_2BgMJ0D4);
  numBytes += sEnv_init(&sEnv_bAbrHjx2, 1024, 512);
  numBytes += sRPole_init(&sRPole_EzTMnGgS);
  numBytes += sLine_init(&sLine_XBJlmObX);
  numBytes += sLine_init(&sLine_HvyAKPVz);
  numBytes += sRPole_init(&sRPole_A8HWPBCg);
  numBytes += sEnv_init(&sEnv_vZgAywzG, 1024, 512);
  numBytes += sRPole_init(&sRPole_Uf9qDrRD);
  numBytes += cVar_init_f(&cVar_LzztLcYc, 0.0f);
  numBytes += cVar_init_f(&cVar_B4rRIqFW, 0.0f);
  numBytes += cVar_init_f(&cVar_4aE1sgS3, 0.0f);
  numBytes += cVar_init_f(&cVar_iGCmUxE5, 0.0f);
  numBytes += cSlice_init(&cSlice_6VLrBvWw, 1, -1);
  numBytes += cVar_init_f(&cVar_Df9dZLlm, 1337.0f);
  numBytes += cVar_init_f(&cVar_c0j7NZGh, 0.0f);
  numBytes += cIf_init(&cIf_IKMNNvU6, false);
  numBytes += cIf_init(&cIf_CUrzGOEM, false);
  numBytes += cBinop_init(&cBinop_PCNRcLUz, 0.0f); // __pow
  numBytes += cIf_init(&cIf_mxLA3VBf, false);
  numBytes += cBinop_init(&cBinop_Fdd8dKvO, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Aoh1vjF1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_oXPQ0SUk, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_0t2IY2G0, 0.0f);
  numBytes += cIf_init(&cIf_wbqP08KD, false);
  numBytes += cIf_init(&cIf_0OcsyflX, false);
  numBytes += cBinop_init(&cBinop_k7fkfIn3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_RAi1hzQu, false);
  numBytes += cBinop_init(&cBinop_oMJfAf91, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_hmGjKKPP, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_mtGD0TJR, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_UHpyF3zH, 0.0f);
  numBytes += cIf_init(&cIf_00CFi9Xx, false);
  numBytes += cIf_init(&cIf_gwp4K3kO, false);
  numBytes += cBinop_init(&cBinop_Gp7vCCYC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_YZ2X0W4G, false);
  numBytes += cBinop_init(&cBinop_TdPK2Bq2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ynadUzse, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_evwKNZYD, -15.0f); // __eq
  numBytes += cIf_init(&cIf_1F7fn1at, false);
  numBytes += cSlice_init(&cSlice_maAcErMM, 1, -1);
  numBytes += cVar_init_f(&cVar_s3egpIrA, 0.0f);
  numBytes += cSlice_init(&cSlice_psINb1I7, 1, -1);
  numBytes += cVar_init_f(&cVar_5JzMhTuJ, 0.0f);
  numBytes += cSlice_init(&cSlice_dV0Nh6v3, 1, -1);
  numBytes += cVar_init_f(&cVar_yzXQ9Wpb, 0.0f);
  numBytes += cSlice_init(&cSlice_WIUuj5SM, 1, -1);
  numBytes += cVar_init_f(&cVar_UbeD2fzP, 0.313f);
  numBytes += cBinop_init(&cBinop_idFN3Tfz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_fnePqgsK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_jrqWe6J8, 0.0f);
  numBytes += cVar_init_f(&cVar_bb8dcoSk, 1337.0f);
  numBytes += cVar_init_f(&cVar_zfhNzdJk, 0.3f);
  numBytes += cBinop_init(&cBinop_XP9VsMr3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V6rUF9N3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FgTj4A3N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_v9tmwgEJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VYquva8i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DWJvBGNX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_re6rpozQ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_uKlX57Tw, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_hLe8qsaF, 0.0f);
  numBytes += cVar_init_f(&cVar_0e6oZMxd, 1337.0f);
  numBytes += cVar_init_f(&cVar_YLCsbZHI, 0.313f);
  numBytes += cBinop_init(&cBinop_Izz07OIj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cb1AkErg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ilIzDIoN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yslSTmUa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fbE0VWs9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aO6sKgs9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_5VsmAeJT, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PPOWjGQr, 0.0f);
  numBytes += cVar_init_f(&cVar_x8EI0wk5, 1037.0f);
  numBytes += cVar_init_f(&cVar_nhuDGgX5, 0.4f);
  numBytes += cBinop_init(&cBinop_BKcGlzlW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Rvz47DbC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qvoZrJ2C, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Kb2jql2g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xO8yTVLG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FvTw9jVI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Ma9vMFrN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yPuZhdyW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YGEuvxlp, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_fWSYsxFS, 1, -1);
  numBytes += cVar_init_f(&cVar_6huIPzbe, 1337.0f);
  numBytes += cVar_init_f(&cVar_DiWzRs1T, 0.0f);
  numBytes += cIf_init(&cIf_m38XO1wr, false);
  numBytes += cIf_init(&cIf_icNAbTAH, false);
  numBytes += cBinop_init(&cBinop_KFSzc6E8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_mb2tahmH, false);
  numBytes += cBinop_init(&cBinop_YeZenIud, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_AN9fS4SC, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_m2jGGst0, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_W2ZIFUYj, 0.0f);
  numBytes += cIf_init(&cIf_kJbaI1iq, false);
  numBytes += cIf_init(&cIf_CDibWM64, false);
  numBytes += cBinop_init(&cBinop_vqDlE6J1, 0.0f); // __pow
  numBytes += cIf_init(&cIf_zqW37sQj, false);
  numBytes += cBinop_init(&cBinop_RV0QRpFp, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_zpLf0PT0, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1jmMjGkm, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_1dwSsGsm, 0.0f);
  numBytes += cIf_init(&cIf_L80H0yCc, false);
  numBytes += cIf_init(&cIf_fx8YHlo5, false);
  numBytes += cBinop_init(&cBinop_aKnLGFp3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_wULIEPXw, false);
  numBytes += cBinop_init(&cBinop_5cVzkFCs, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YE8UmCO3, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_TZp3Fvbu, -15.0f); // __eq
  numBytes += cIf_init(&cIf_U9KRiWjC, false);
  numBytes += cSlice_init(&cSlice_2hQy56Vf, 1, -1);
  numBytes += cVar_init_f(&cVar_BWDko8m5, 0.0f);
  numBytes += cSlice_init(&cSlice_zH3PRMmH, 1, -1);
  numBytes += cVar_init_f(&cVar_xVTILxzO, 0.0f);
  numBytes += cSlice_init(&cSlice_nQmTUydO, 1, -1);
  numBytes += cVar_init_f(&cVar_3zntZfTD, 0.0f);
  numBytes += cSlice_init(&cSlice_L4ouSIOF, 1, -1);
  numBytes += cVar_init_f(&cVar_emk0YOaG, 0.313f);
  numBytes += cBinop_init(&cBinop_oRgn8ZSt, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dlPccD6X, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_VBNeJocK, 0.0f);
  numBytes += cVar_init_f(&cVar_srNpwRyP, 1337.0f);
  numBytes += cVar_init_f(&cVar_Y1muCR9P, 0.3f);
  numBytes += cBinop_init(&cBinop_nfDeghfY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WgY5rNhW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lBQZ8mmp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rdQvgjGO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ab4ERtBd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_shQU6DxH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cGGZ7mdo, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dhQbBnCj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_mWQos0iy, 0.0f);
  numBytes += cVar_init_f(&cVar_dLfxWxiC, 1337.0f);
  numBytes += cVar_init_f(&cVar_Kz4Q48ZQ, 0.313f);
  numBytes += cBinop_init(&cBinop_UL93fpcB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JMhqUXOO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kgpCsivV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sxMzCk0Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_obVxIYKA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3GqE3Qoj, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ctTeoJAt, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_kwXzIFel, 0.0f);
  numBytes += cVar_init_f(&cVar_8G1o3Ixx, 1037.0f);
  numBytes += cVar_init_f(&cVar_NdALQG5o, 0.4f);
  numBytes += cBinop_init(&cBinop_K1Piue1l, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_phaQ1BsN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_N152sTGF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3cYqtMnE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NrviormF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tByyuR4T, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VEsORcS7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SOvOdmT7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8vgK8q2A, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Ut0MAWD1, 5705.6f);
  numBytes += cVar_init_f(&cVar_CO65YgiW, 313.3f);
  numBytes += cBinop_init(&cBinop_7rp1uS9Q, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_QhDVO8Tt, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_OKfhpvGB, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_EkcRcnNg, 0.0f);
  numBytes += cVar_init_f(&cVar_kW333plv, 0.0f);
  numBytes += cVar_init_f(&cVar_65RMxHSF, 0.0f);
  numBytes += cVar_init_f(&cVar_CAq5BeJY, 0.0f);
  numBytes += cVar_init_f(&cVar_sIy2ju4I, 0.0f);
  numBytes += cVar_init_f(&cVar_JhEhH5rO, 0.0f);
  numBytes += cVar_init_f(&cVar_GuTTrRUb, 0.0f);
  numBytes += cVar_init_f(&cVar_DdpKo0v7, 0.0f);
  numBytes += cVar_init_f(&cVar_y6UKHuvy, 0.0f);
  numBytes += cVar_init_f(&cVar_gTOE3GeV, 0.0f);
  numBytes += cVar_init_f(&cVar_Cg6BIfZB, 0.0f);
  numBytes += cVar_init_f(&cVar_6Lt3xio0, 0.0f);
  numBytes += cSlice_init(&cSlice_o8pOWhFt, 1, -1);
  numBytes += cVar_init_f(&cVar_UbChdC6O, 0.5f);
  numBytes += cSlice_init(&cSlice_3makVIlX, 1, -1);
  numBytes += cVar_init_f(&cVar_R0YmKN59, 0.2f);
  numBytes += cSlice_init(&cSlice_d1unY20j, 1, -1);
  numBytes += cVar_init_f(&cVar_RXhXU9dS, 500.0f);
  numBytes += sVarf_init(&sVarf_otbMVUga, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_eylp7s1f, 600.0f);
  numBytes += cBinop_init(&cBinop_1yevOqA9, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_1AC8qUtn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2beDsilW, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_D8Pcv1aD, 600.0f);
  numBytes += cBinop_init(&cBinop_ufuJlv9N, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_K8wUAsoQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_d19RT6Bu, 4000.0f);
  numBytes += cBinop_init(&cBinop_kT0gAl9r, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_gMikaZQe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6gj6aMYw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bx89yx6D, 4000.0f);
  numBytes += cBinop_init(&cBinop_iWLoha5s, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ipL62r7u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bRmQVy3n, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_oBgtKT0R, false);
  numBytes += cBinop_init(&cBinop_AAUhKhNC, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_RwkghXtC, 20.0f);
  numBytes += cBinop_init(&cBinop_uGFiwKvM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_YkZDzIKr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VUO83LzB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tLsFDF0J, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_WgnxmcVh, false);
  numBytes += cBinop_init(&cBinop_Lt0tKNu7, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_LTX87KUK, 20.0f);
  numBytes += cBinop_init(&cBinop_Em8udKNl, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_y8Gq0zGl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bANcYv5C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zf4W2DkK, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_ReYnj3Hg, 1, -1);
  numBytes += cVar_init_f(&cVar_9uf78VUI, 0.25f);
  numBytes += cDelay_init(this, &cDelay_VJ0TRFMH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_LE2YWA1s, 0.0f);
  numBytes += hTable_init(&hTable_bfMHjUIg, 256);
  numBytes += cTabhead_init(&cTabhead_FvjB1YIG, &hTable_bfMHjUIg);
  numBytes += cVar_init_s(&cVar_EBLqxK4p, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_4zYNvNs2, 0.0f);
  numBytes += cDelay_init(this, &cDelay_7B98ZSaW, 0.0f);
  numBytes += cBinop_init(&cBinop_h8aTTjn9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ygfC7mHK, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_6RLoQu4t, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_hF7oZ2YH, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_eFPPzsHv, 0.0f);
  numBytes += cDelay_init(this, &cDelay_IyyFLTMY, 0.0f);
  numBytes += hTable_init(&hTable_TKQiRNT0, 256);
  numBytes += cTabhead_init(&cTabhead_7dZD0CDJ, &hTable_TKQiRNT0);
  numBytes += cVar_init_s(&cVar_z6BltCi5, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_pQaDOhQa, 0.0f);
  numBytes += cDelay_init(this, &cDelay_FudEqlS7, 0.0f);
  numBytes += cBinop_init(&cBinop_oISgB9C0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AwBRlMBT, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_U8briahB, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_T6WFsfE5, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_zY6BSVsx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pmp1WIHH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LHOdVape, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s83PKJW2, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_qoweblUi, 1, -1);
  numBytes += cVar_init_f(&cVar_5x10O98S, 0.5f);
  numBytes += cSlice_init(&cSlice_tKOT8YmH, 1, -1);
  numBytes += cVar_init_f(&cVar_E1WbXSlV, 0.2f);
  numBytes += cSlice_init(&cSlice_M9xOOAf0, 1, -1);
  numBytes += cVar_init_f(&cVar_B8KOLt4y, 500.0f);
  numBytes += sVarf_init(&sVarf_4jc96OSn, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gONEQ4Z5, 600.0f);
  numBytes += cBinop_init(&cBinop_mgLzcW0k, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_7yW6cXFh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_09e4BcNL, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lcDExF26, 600.0f);
  numBytes += cBinop_init(&cBinop_cZ8Sf3xH, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_701SoLRi, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_QUbP8eKY, 4000.0f);
  numBytes += cBinop_init(&cBinop_akA0xvz2, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_r3VyMjQs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gPX0lrb6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Dlj2t921, 4000.0f);
  numBytes += cBinop_init(&cBinop_q9QzGMIS, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_CumH3e2n, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OBW5daYB, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_2BaQD8r2, false);
  numBytes += cBinop_init(&cBinop_AyOLF2zY, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_kvHiK7dt, 20.0f);
  numBytes += cBinop_init(&cBinop_eRSvF3fN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tMaHM2sj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v4rq4hGI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m3CG3nev, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_VBBJzLsa, false);
  numBytes += cBinop_init(&cBinop_O8i5y7rb, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_CPdJAFYo, 20.0f);
  numBytes += cBinop_init(&cBinop_gcKPFHCv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_3mVDW4Oj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_orUszSzE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OZ2fwsGT, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_gD9ksRAy, 1, -1);
  numBytes += cVar_init_f(&cVar_XaU7Sz0H, 0.25f);
  numBytes += cDelay_init(this, &cDelay_p3IuRv3X, 0.0f);
  numBytes += cDelay_init(this, &cDelay_E1ZGKPUi, 0.0f);
  numBytes += hTable_init(&hTable_zi1xCbSs, 256);
  numBytes += cTabhead_init(&cTabhead_T0sUfdBM, &hTable_zi1xCbSs);
  numBytes += cVar_init_s(&cVar_jcDNXssg, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_EcHlhpWZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_10RMyi5M, 0.0f);
  numBytes += cBinop_init(&cBinop_Wl25FzEg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1KnvCR1r, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9Gcr1I5O, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_QRR0d1cY, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Qsnw62W7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dG4wTvt9, 0.0f);
  numBytes += hTable_init(&hTable_pY6tUaMi, 256);
  numBytes += cTabhead_init(&cTabhead_vKb9CMYG, &hTable_pY6tUaMi);
  numBytes += cVar_init_s(&cVar_kugbDvZO, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_yDDLRADH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_skokD83W, 0.0f);
  numBytes += cBinop_init(&cBinop_GASsbMoK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6Bt0ep8P, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_AdB5vU2X, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_qBR2SgUk, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_JXI3C9vk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UndcrrtM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XnfwZdb2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GrNr1xC0, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_3Jn4nutr, 1, -1);
  numBytes += cVar_init_f(&cVar_bTOTsKue, 0.5f);
  numBytes += cSlice_init(&cSlice_gsusoO4k, 1, -1);
  numBytes += cVar_init_f(&cVar_pO07ndbi, 0.2f);
  numBytes += cSlice_init(&cSlice_sH3G1s3a, 1, -1);
  numBytes += cVar_init_f(&cVar_5sqogDZn, 500.0f);
  numBytes += sVarf_init(&sVarf_vjLrYkOT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FMF63Tv4, 600.0f);
  numBytes += cBinop_init(&cBinop_WMwQN6U4, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_iD2ndKwx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QVruoT5w, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_RgSXQ6Ex, 600.0f);
  numBytes += cBinop_init(&cBinop_fVmxRlb7, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_RaJtEtDr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MrNpvIbQ, 4000.0f);
  numBytes += cBinop_init(&cBinop_30Ry7vR9, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GELHL6Aw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LZsoioyI, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NeqdAKNK, 4000.0f);
  numBytes += cBinop_init(&cBinop_DlbRTiBd, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_x336dEz1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oLo0vntp, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_Yo8JILt7, false);
  numBytes += cBinop_init(&cBinop_oyFTPaEo, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_Kwu72uXX, 20.0f);
  numBytes += cBinop_init(&cBinop_pVGXWQn2, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lzRsk3RJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_svB0pd43, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rtjfwUpU, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_NuZz3UQR, false);
  numBytes += cBinop_init(&cBinop_dtQretUV, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_I8kREM0T, 20.0f);
  numBytes += cBinop_init(&cBinop_8SbOFIVD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_b28JK72s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pZLZpwWB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HXJdsKi5, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_3UG4yn41, 1, -1);
  numBytes += cVar_init_f(&cVar_SojMX6VO, 0.25f);
  numBytes += cDelay_init(this, &cDelay_TRhHzP45, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wIvoidfk, 0.0f);
  numBytes += hTable_init(&hTable_2SDigbFI, 256);
  numBytes += cTabhead_init(&cTabhead_Kfps82ov, &hTable_2SDigbFI);
  numBytes += cVar_init_s(&cVar_MG9wmBeV, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_xCgDs6ww, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Qthurju8, 0.0f);
  numBytes += cBinop_init(&cBinop_1PkQxAs4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YLWJGWK8, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_eEdiox49, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_H9NLToeJ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_ju4x0HVI, 0.0f);
  numBytes += cDelay_init(this, &cDelay_oihMj5BV, 0.0f);
  numBytes += hTable_init(&hTable_Y4T68Ejp, 256);
  numBytes += cTabhead_init(&cTabhead_3rADAviv, &hTable_Y4T68Ejp);
  numBytes += cVar_init_s(&cVar_ge7OnMJZ, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_NvRPtXmN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qUNKvCHI, 0.0f);
  numBytes += cBinop_init(&cBinop_o2IGTXmX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3gPbEPNu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_h7m3QvWH, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_4hSqpDYT, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_rWWWKfqJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ztQXTHOs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ltg8E5jn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_daQX3ia4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_mVprwGoi, 1.0f);
  numBytes += cIf_init(&cIf_Ihd4AkXs, false);
  numBytes += cIf_init(&cIf_1VaZpF9y, false);
  numBytes += cVar_init_f(&cVar_sg7O6g1V, 0.0f);
  numBytes += cVar_init_f(&cVar_SGahUbph, 0.0f);
  numBytes += cVar_init_f(&cVar_9KCz3Weo, 1.0f);
  numBytes += cIf_init(&cIf_jk6bS1gA, false);
  numBytes += cIf_init(&cIf_7JyyIvC4, false);
  numBytes += cVar_init_f(&cVar_AGCYOSix, 0.0f);
  numBytes += cVar_init_f(&cVar_vltitniV, 0.0f);
  numBytes += cVar_init_f(&cVar_9vtC2iTf, 1.0f);
  numBytes += cIf_init(&cIf_zsMRKFO9, false);
  numBytes += cIf_init(&cIf_P4CJBV8T, false);
  numBytes += cVar_init_f(&cVar_VldcZ6qy, 0.0f);
  numBytes += cVar_init_f(&cVar_uSfkmWQx, 0.0f);
  numBytes += cVar_init_f(&cVar_Z091udTh, 60000.0f);
  numBytes += cVar_init_f(&cVar_3TDg6Kvh, 500.0f);
  numBytes += cSlice_init(&cSlice_LvoUR2tC, 1, -1);
  numBytes += cSlice_init(&cSlice_LJr5Pee7, 1, -1);
  numBytes += cVar_init_f(&cVar_TsqfhV0y, 0.0f);
  numBytes += cIf_init(&cIf_vujapMr7, false);
  numBytes += cBinop_init(&cBinop_BxE98gUb, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_KPu9MNSV, 120.0f);
  numBytes += cBinop_init(&cBinop_TRmVswuH, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_NwkvZ0Yj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xGHy34jo, 60000.0f);
  numBytes += cVar_init_f(&cVar_vwuN0WQ4, 500.0f);
  numBytes += cSlice_init(&cSlice_NAQPIfPx, 1, -1);
  numBytes += cSlice_init(&cSlice_ph3XhQuF, 1, -1);
  numBytes += cVar_init_f(&cVar_8Z6p9VoX, 0.0f);
  numBytes += cIf_init(&cIf_MWCYOd6n, false);
  numBytes += cBinop_init(&cBinop_YbUQHla7, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_VQ0xra4U, 120.0f);
  numBytes += cBinop_init(&cBinop_GbwFRszW, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_oG4dNhkj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_jivRNL0z, 60000.0f);
  numBytes += cVar_init_f(&cVar_aPrGTfwu, 500.0f);
  numBytes += cSlice_init(&cSlice_90nUyomV, 1, -1);
  numBytes += cSlice_init(&cSlice_r8RI7OJt, 1, -1);
  numBytes += cVar_init_f(&cVar_nScX1eb6, 0.0f);
  numBytes += cIf_init(&cIf_YD1NMwx1, false);
  numBytes += cBinop_init(&cBinop_ODHbiZpc, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_2xkrVAsD, 120.0f);
  numBytes += cBinop_init(&cBinop_9VaknWYe, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_loVjtXab, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_7DOxTcFR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eWlSMkVc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FRM1AQT6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sLuTOy4F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_my0sFozl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LpYcvzIO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VeOjnPMa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MOlUcSih, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PJdO7Fcc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e5NfP7N0, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_nANzx3UD);
  sEnv_free(&sEnv_rZJppz6b);
  sEnv_free(&sEnv_9eZh7Kzo);
  sEnv_free(&sEnv_emHV5Ijb);
  sEnv_free(&sEnv_bAbrHjx2);
  sEnv_free(&sEnv_vZgAywzG);
  hTable_free(&hTable_bfMHjUIg);
  hTable_free(&hTable_TKQiRNT0);
  hTable_free(&hTable_zi1xCbSs);
  hTable_free(&hTable_pY6tUaMi);
  hTable_free(&hTable_2SDigbFI);
  hTable_free(&hTable_Y4T68Ejp);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_bfMHjUIg; // del-1349-delayL
    case 0x19A00729: return &hTable_TKQiRNT0; // del-1349-delayR
    case 0x584C8281: return &hTable_zi1xCbSs; // del-1428-delayL
    case 0x54BF59F6: return &hTable_pY6tUaMi; // del-1428-delayR
    case 0xBCE693A: return &hTable_2SDigbFI; // del-1507-delayL
    case 0x95A380B3: return &hTable_Y4T68Ejp; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xAVmnkjo_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J9yiTXU8_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZjHOXT5m_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NmoiFV9v_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FXz3F7GT_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jsw3Jas8_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s1IINFvG_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y3E5Myxu_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OSGtZO6d_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MThobnlb_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_asrSXUeQ_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HSrIgGBP_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7XxwxxYa_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8mEswe5j_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CIWE3764_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hh2H21FA_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3zpFIXVg_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rauuwxI3_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uw7a7hy2_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wr0ovAjf_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1RRNSWfj_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EIDwrQld_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8AdG0UVe_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FYVVtasz_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AaAkHgZE_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GDcOZFO7_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nBO0VYqQ_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gDWlPwm3_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6VVuGXHV_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l8CgjMx5_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YF96WmzF_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0PEKeT99_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P4NTg8NI_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nQxi0Eeh_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DmRqeUDT_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1RMEelH6_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hDGyZFGR_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yx5UxUba_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CINtlk0z_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VX77yWG1_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2cHyo2C8_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5BD8Iqif_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MHgaDBcG_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NHvwYyeI_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V3Bjsuj1_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FfC7h50X_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SxXu2IbT_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_afWdFgXd_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bu4iSiFY_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XCZrvY9F_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u88eovKD_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qr36bNun_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6RiIExtb_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CkCQ85nl_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MxpDbN6S_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xL7JRL9N_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kFiPBE2y_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jJq7P1hF_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VtuDC3Jf_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LTuYjWZv_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uyPxIws0_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nIp0rFn8_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2PP068sL_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wFaawDjk_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_LzztLcYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G6HT297I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_B4rRIqFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7DfE6JiD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4aE1sgS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kjXMSWae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_iGCmUxE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lfITEaeg_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8H3YnNiQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JHtWRlMa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wLYKepsR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7SQqM56l_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6VLrBvWw, 0, m, &cSlice_6VLrBvWw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DYsdQykZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_6VLrBvWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_t6yB4yOp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_t6yB4yOp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Df9dZLlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t6yB4yOp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_t6yB4yOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AaAkHgZE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_c0j7NZGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qHONhDV5_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_IKMNNvU6, 0, m, &cIf_IKMNNvU6_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_IKMNNvU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TWejk8kc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_CUrzGOEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WH5IQSKo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_APsLhjPt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_2B6ly7x4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PCNRcLUz, HV_BINOP_POW, 0, m, &cBinop_PCNRcLUz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PCNRcLUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mxLA3VBf, 0, m, &cIf_mxLA3VBf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WtH6mDsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_iuGtLJY2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nVihx0d8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FZbp9y4o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EIhVFaVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CUrzGOEM, 0, m, &cIf_CUrzGOEM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FZbp9y4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CUrzGOEM, 1, m, &cIf_CUrzGOEM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_APsLhjPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_WtH6mDsz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WH5IQSKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mxLA3VBf, 0, m, &cIf_mxLA3VBf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iuGtLJY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PCNRcLUz, HV_BINOP_POW, 1, m, &cBinop_PCNRcLUz_sendMessage);
  cMsg_2B6ly7x4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_mxLA3VBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Ma9vMFrN, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_qHONhDV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IKMNNvU6, 1, m, &cIf_IKMNNvU6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TWejk8kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Aoh1vjF1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Aoh1vjF1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oXPQ0SUk, HV_BINOP_EQ, 1, m, &cBinop_oXPQ0SUk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6PBPwmll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fdd8dKvO, HV_BINOP_ADD, 0, m, &cBinop_Fdd8dKvO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Fdd8dKvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nVihx0d8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EIhVFaVs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Aoh1vjF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mxLA3VBf, 1, m, &cIf_mxLA3VBf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oXPQ0SUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IJ7ZnyIE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_IJ7ZnyIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ma9vMFrN, m);
}

void Heavy_WSTD_DL3Y::cCast_JC75pLO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c0j7NZGh, 0, m, &cVar_c0j7NZGh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fg2Xba0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fdd8dKvO, HV_BINOP_ADD, 1, m, &cBinop_Fdd8dKvO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Aoh1vjF1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Aoh1vjF1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oXPQ0SUk, HV_BINOP_EQ, 0, m, &cBinop_oXPQ0SUk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_S9wAiGJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6PBPwmll_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_0t2IY2G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R6IbUciu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_wbqP08KD, 0, m, &cIf_wbqP08KD_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_wbqP08KD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PgmTN9qi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_0OcsyflX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_BQ2XLCp5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_jazXTX1d_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_ANzxcSTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_k7fkfIn3, HV_BINOP_POW, 0, m, &cBinop_k7fkfIn3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k7fkfIn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RAi1hzQu, 0, m, &cIf_RAi1hzQu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GHr4rI6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ja53qS5c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QgXv9Zl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_67p7sPrQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_df5D4TJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0OcsyflX, 0, m, &cIf_0OcsyflX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_67p7sPrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0OcsyflX, 1, m, &cIf_0OcsyflX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jazXTX1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GHr4rI6P_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BQ2XLCp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_RAi1hzQu, 0, m, &cIf_RAi1hzQu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ja53qS5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k7fkfIn3, HV_BINOP_POW, 1, m, &cBinop_k7fkfIn3_sendMessage);
  cMsg_ANzxcSTM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_RAi1hzQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VmzazEck_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NrmPN854_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_UfyPUKwq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_R6IbUciu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wbqP08KD, 1, m, &cIf_wbqP08KD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PgmTN9qi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hmGjKKPP, HV_BINOP_GREATER_THAN, 1, m, &cBinop_hmGjKKPP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mtGD0TJR, HV_BINOP_EQ, 1, m, &cBinop_mtGD0TJR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0lgB7qBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oMJfAf91, HV_BINOP_ADD, 0, m, &cBinop_oMJfAf91_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oMJfAf91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QgXv9Zl2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_df5D4TJ1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hmGjKKPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RAi1hzQu, 1, m, &cIf_RAi1hzQu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mtGD0TJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BYjaY37m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_BYjaY37m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VmzazEck_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NrmPN854_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_UfyPUKwq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8ukgKxsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0t2IY2G0, 0, m, &cVar_0t2IY2G0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Y6X2lF9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oMJfAf91, HV_BINOP_ADD, 1, m, &cBinop_oMJfAf91_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hmGjKKPP, HV_BINOP_GREATER_THAN, 0, m, &cBinop_hmGjKKPP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mtGD0TJR, HV_BINOP_EQ, 0, m, &cBinop_mtGD0TJR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LcRaS21M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0lgB7qBU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_UHpyF3zH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lAT9hZlG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_00CFi9Xx, 0, m, &cIf_00CFi9Xx_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_00CFi9Xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1VsPyaWG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_gwp4K3kO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_xOA0y9DJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Ew9eZQnk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_IJQgL5jB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gp7vCCYC, HV_BINOP_POW, 0, m, &cBinop_Gp7vCCYC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gp7vCCYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YZ2X0W4G, 0, m, &cIf_YZ2X0W4G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P55HbAop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_KUqjW5JC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xhU9IoVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gwp4K3kO, 0, m, &cIf_gwp4K3kO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ECsAln0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_m7tolSPc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m7tolSPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gwp4K3kO, 1, m, &cIf_gwp4K3kO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ew9eZQnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_P55HbAop_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xOA0y9DJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YZ2X0W4G, 0, m, &cIf_YZ2X0W4G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KUqjW5JC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gp7vCCYC, HV_BINOP_POW, 1, m, &cBinop_Gp7vCCYC_sendMessage);
  cMsg_IJQgL5jB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_YZ2X0W4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YGEuvxlp, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_lAT9hZlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_00CFi9Xx, 1, m, &cIf_00CFi9Xx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1VsPyaWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ynadUzse, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ynadUzse_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_evwKNZYD, HV_BINOP_EQ, 1, m, &cBinop_evwKNZYD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8UGsNbqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TdPK2Bq2, HV_BINOP_ADD, 0, m, &cBinop_TdPK2Bq2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TdPK2Bq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ECsAln0A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xhU9IoVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ynadUzse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YZ2X0W4G, 1, m, &cIf_YZ2X0W4G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_evwKNZYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VXsbN4W2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_VXsbN4W2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YGEuvxlp, m);
}

void Heavy_WSTD_DL3Y::cCast_T04j9ap2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8UGsNbqR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_n3pvo66n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UHpyF3zH, 0, m, &cVar_UHpyF3zH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ITvf5BCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TdPK2Bq2, HV_BINOP_ADD, 1, m, &cBinop_TdPK2Bq2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ynadUzse, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ynadUzse_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_evwKNZYD, HV_BINOP_EQ, 0, m, &cBinop_evwKNZYD_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_1F7fn1at_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_yPuZhdyW, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_CvwSeWX0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_maAcErMM, 0, m, &cSlice_maAcErMM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zjR8REgH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_maAcErMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jMHUXKAX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jMHUXKAX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_s3egpIrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jMHUXKAX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_jMHUXKAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8AdG0UVe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zjR8REgH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_psINb1I7, 0, m, &cSlice_psINb1I7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7SQqM56l_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_psINb1I7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SmHeC6Hb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SmHeC6Hb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_5JzMhTuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SmHeC6Hb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SmHeC6Hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nBO0VYqQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_DYsdQykZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dV0Nh6v3, 0, m, &cSlice_dV0Nh6v3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_a3eE55j8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_dV0Nh6v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qK0vxg36_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qK0vxg36_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_yzXQ9Wpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qK0vxg36_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qK0vxg36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FYVVtasz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_a3eE55j8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WIUuj5SM, 0, m, &cSlice_WIUuj5SM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_WIUuj5SM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fQRrPX0c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fQRrPX0c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_UbeD2fzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fQRrPX0c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_fQRrPX0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GDcOZFO7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Gtw0xcLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZvAgF9N8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_H1OlsRLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_we3l5QFX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fWbdKYfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F87eOyfa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_A4bZ8yEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HyU76aGI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xjomj5nD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8C7CWo4U, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3NhkKqdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZkFrg14Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ZkFrg14Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_idFN3Tfz, HV_BINOP_DIVIDE, 1, m, &cBinop_idFN3Tfz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aRs2wo1m_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_hZaB7nB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Sx97jKDW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0I8gpZLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_hZaB7nB2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sx97jKDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_idFN3Tfz, HV_BINOP_DIVIDE, 0, m, &cBinop_idFN3Tfz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aRs2wo1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0I8gpZLc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_idFN3Tfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fnePqgsK, HV_BINOP_MULTIPLY, 1, m, &cBinop_fnePqgsK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fnePqgsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZCGuOYzl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3qtLJUTn_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_vBqPo5d6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AgjIViev_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_yuta596i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_F2c7zMM3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rwq1tfDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HsFDiqxU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HsFDiqxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fnePqgsK, HV_BINOP_MULTIPLY, 0, m, &cBinop_fnePqgsK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9C1ord2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ixWDagac_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ixWDagac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kW1jfjAj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gLaw1gBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jrqWe6J8, 1, m, &cVar_jrqWe6J8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_jrqWe6J8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a1Yl2X84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_478DdUSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V6rUF9N3, HV_BINOP_MULTIPLY, 1, m, &cBinop_V6rUF9N3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vor0775W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_478DdUSP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vQAi91G9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BqSk8pUw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BqSk8pUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FgTj4A3N, HV_BINOP_MULTIPLY, 1, m, &cBinop_FgTj4A3N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F16dr8Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v9tmwgEJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_v9tmwgEJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KENhhsDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_F16dr8Lr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KAsbSVuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VYquva8i, HV_BINOP_MULTIPLY, 1, m, &cBinop_VYquva8i_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ffBu1g2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gO9yRP1d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gO9yRP1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DWJvBGNX, HV_BINOP_MULTIPLY, 1, m, &cBinop_DWJvBGNX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bb8dcoSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_isUjc205_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_rwq1tfDw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hN5skv6m_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zfhNzdJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9C1ord2H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3qtLJUTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_yuta596i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZCGuOYzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_vBqPo5d6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_AgjIViev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l8CgjMx5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_F2c7zMM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6VVuGXHV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_vocnMSU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gDWlPwm3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_kW1jfjAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tFL3TMPt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tFL3TMPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XP9VsMr3, HV_BINOP_MULTIPLY, 1, m, &cBinop_XP9VsMr3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XP9VsMr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vdYlIh4H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vdYlIh4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vocnMSU7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_a1Yl2X84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ohImvt9K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ohImvt9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5I88m5cq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E664KjYh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wlny7ZJv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aYuEo6nj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_23KNzjM8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BsbUjsVQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V6rUF9N3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gtw0xcLp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FgTj4A3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H1OlsRLH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_v9tmwgEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fWbdKYfa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VYquva8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A4bZ8yEW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DWJvBGNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xjomj5nD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_GDco9ozS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bb8dcoSk, 0, m, &cVar_bb8dcoSk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WmnNq2A0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zfhNzdJk, 1, m, &cVar_zfhNzdJk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_23KNzjM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FgTj4A3N, HV_BINOP_MULTIPLY, 0, m, &cBinop_FgTj4A3N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BsbUjsVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V6rUF9N3, HV_BINOP_MULTIPLY, 0, m, &cBinop_V6rUF9N3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aYuEo6nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v9tmwgEJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_v9tmwgEJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Wlny7ZJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VYquva8i, HV_BINOP_MULTIPLY, 0, m, &cBinop_VYquva8i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5I88m5cq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_E664KjYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DWJvBGNX, HV_BINOP_MULTIPLY, 0, m, &cBinop_DWJvBGNX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_isUjc205_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zfhNzdJk, 0, m, &cVar_zfhNzdJk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hN5skv6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jrqWe6J8, 0, m, &cVar_jrqWe6J8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kvG2TWMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wnDeZ73n, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2VFBIsXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5IFJj3U6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Y2TGO4s9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AsHt4w2x, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_er8Ly0NP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0ef5wMEw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_udOyROX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_34pVoRmz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_34pVoRmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_re6rpozQ, HV_BINOP_DIVIDE, 1, m, &cBinop_re6rpozQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MhPFdubo_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_BKiLRq4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Hf39eano_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eyZtjTqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_BKiLRq4E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hf39eano_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_re6rpozQ, HV_BINOP_DIVIDE, 0, m, &cBinop_re6rpozQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MhPFdubo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eyZtjTqC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_re6rpozQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uKlX57Tw, HV_BINOP_MULTIPLY, 1, m, &cBinop_uKlX57Tw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uKlX57Tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c1bxNkyG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x63MxZjW_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_IioaPgjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JWA4R0sF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_krhP4QoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lp00aonT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_p7g1fRTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_YQFwcEPF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YQFwcEPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uKlX57Tw, HV_BINOP_MULTIPLY, 0, m, &cBinop_uKlX57Tw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oPvlAdwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_7SL1bngH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7SL1bngH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8v1BCBlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fa6Mrpwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ilIzDIoN, HV_BINOP_MULTIPLY, 1, m, &cBinop_ilIzDIoN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x1mwhtHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hLe8qsaF, 1, m, &cVar_hLe8qsaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_USraVv2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yslSTmUa, HV_BINOP_MULTIPLY, 1, m, &cBinop_yslSTmUa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bFCluFvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FmICETVl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FmICETVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fbE0VWs9, HV_BINOP_MULTIPLY, 1, m, &cBinop_fbE0VWs9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_hLe8qsaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_veVwzIVD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_0e6oZMxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ihztADVQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_p7g1fRTj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EZ5shaXh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_YLCsbZHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oPvlAdwq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_x63MxZjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_krhP4QoX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c1bxNkyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_IioaPgjv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_JWA4R0sF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_P4NTg8NI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_lp00aonT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0PEKeT99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_2lHdcVkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YF96WmzF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_8v1BCBlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1ZP7NGmw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1ZP7NGmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Izz07OIj, HV_BINOP_MULTIPLY, 1, m, &cBinop_Izz07OIj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Izz07OIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SvOEtOli_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SvOEtOli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2lHdcVkv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_veVwzIVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oMpUJBp8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oMpUJBp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XUt4vF8M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bMjU9CPw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yPE1hnRW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mvJFMgaa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cb1AkErg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kvG2TWMq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ilIzDIoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2VFBIsXd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yslSTmUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y2TGO4s9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fbE0VWs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_er8Ly0NP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_y5kiO9Am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0e6oZMxd, 0, m, &cVar_0e6oZMxd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DrGkBJka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YLCsbZHI, 1, m, &cVar_YLCsbZHI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ihztADVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YLCsbZHI, 0, m, &cVar_YLCsbZHI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EZ5shaXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hLe8qsaF, 0, m, &cVar_hLe8qsaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mvJFMgaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cb1AkErg, HV_BINOP_MULTIPLY, 0, m, &cBinop_cb1AkErg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yPE1hnRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ilIzDIoN, HV_BINOP_MULTIPLY, 0, m, &cBinop_ilIzDIoN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bMjU9CPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yslSTmUa, HV_BINOP_MULTIPLY, 0, m, &cBinop_yslSTmUa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XUt4vF8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fbE0VWs9, HV_BINOP_MULTIPLY, 0, m, &cBinop_fbE0VWs9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HJZKl8lB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nJK8s5ew, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pMgZxczA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PUlM3jbL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JqqW2CPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_beccf2W7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kYmsgqYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j1dsbIxQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NGBned6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qugRxuIp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TIHYa53e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JVlxqUyF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JVlxqUyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aO6sKgs9, HV_BINOP_DIVIDE, 1, m, &cBinop_aO6sKgs9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2sPanpgQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_nrooeceh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_6RGZD4Pe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_63UYI1v2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nrooeceh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6RGZD4Pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aO6sKgs9, HV_BINOP_DIVIDE, 0, m, &cBinop_aO6sKgs9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2sPanpgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_63UYI1v2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aO6sKgs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5VsmAeJT, HV_BINOP_MULTIPLY, 1, m, &cBinop_5VsmAeJT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5VsmAeJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rya0mlkQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fejGU6es_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_6qzgYsOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_27327Omr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_kLhw4CAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nLvJMpnG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_r2mxMK1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_fakzfBzT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fakzfBzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5VsmAeJT, HV_BINOP_MULTIPLY, 0, m, &cBinop_5VsmAeJT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ILkb9nvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_NfUG1s5f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NfUG1s5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SqcTzylZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_W088HuA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rvz47DbC, HV_BINOP_MULTIPLY, 1, m, &cBinop_Rvz47DbC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zvgtpymn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1P4A6ZoG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1P4A6ZoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_W088HuA7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eZgXrhRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZHjsFiFB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZHjsFiFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qvoZrJ2C, HV_BINOP_MULTIPLY, 1, m, &cBinop_qvoZrJ2C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MRxOg0wD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kb2jql2g, HV_BINOP_MULTIPLY, 1, m, &cBinop_Kb2jql2g_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eVzZFn0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tCJ6bMhi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tCJ6bMhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MRxOg0wD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8Esu7zF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PPOWjGQr, 1, m, &cVar_PPOWjGQr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zj9PQ8kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xO8yTVLG, HV_BINOP_MULTIPLY, 1, m, &cBinop_xO8yTVLG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GHlrBTIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tqDZqmov_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tqDZqmov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FvTw9jVI, HV_BINOP_MULTIPLY, 1, m, &cBinop_FvTw9jVI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PPOWjGQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rNIwZHwT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_x8EI0wk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X7uZZwDC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_r2mxMK1A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qroOHcYE_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_nhuDGgX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ILkb9nvS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Rya0mlkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_6qzgYsOR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fejGU6es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_kLhw4CAv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_27327Omr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1RMEelH6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_nLvJMpnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DmRqeUDT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PiyXD1rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nQxi0Eeh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_SqcTzylZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PPAO4Lbp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PPAO4Lbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BKcGlzlW, HV_BINOP_MULTIPLY, 1, m, &cBinop_BKcGlzlW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BKcGlzlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ChamYgay_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ChamYgay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PiyXD1rj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_rNIwZHwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zZaZA7U6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zZaZA7U6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P70Bzo3m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZTSaInsm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_quur04dn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0M53CiXG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3aX6OCl7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5vVmbaRz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rvz47DbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HJZKl8lB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qvoZrJ2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pMgZxczA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Kb2jql2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JqqW2CPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xO8yTVLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kYmsgqYp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FvTw9jVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NGBned6X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_unkVd0MF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nhuDGgX5, 1, m, &cVar_nhuDGgX5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v5B8BrWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x8EI0wk5, 0, m, &cVar_x8EI0wk5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0M53CiXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kb2jql2g, HV_BINOP_MULTIPLY, 0, m, &cBinop_Kb2jql2g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZTSaInsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FvTw9jVI, HV_BINOP_MULTIPLY, 0, m, &cBinop_FvTw9jVI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3aX6OCl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qvoZrJ2C, HV_BINOP_MULTIPLY, 0, m, &cBinop_qvoZrJ2C_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5vVmbaRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rvz47DbC, HV_BINOP_MULTIPLY, 0, m, &cBinop_Rvz47DbC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_P70Bzo3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_quur04dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xO8yTVLG, HV_BINOP_MULTIPLY, 0, m, &cBinop_xO8yTVLG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_X7uZZwDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nhuDGgX5, 0, m, &cVar_nhuDGgX5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qroOHcYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PPOWjGQr, 0, m, &cVar_PPOWjGQr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VmzazEck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1F7fn1at, 1, m, &cIf_1F7fn1at_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZbPQn6ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_yPuZhdyW, m);
}

void Heavy_WSTD_DL3Y::cBinop_NrmPN854_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZbPQn6ih_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UfyPUKwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1F7fn1at, 0, m, &cIf_1F7fn1at_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_LU2BL4hh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fWSYsxFS, 0, m, &cSlice_fWSYsxFS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_l2MlAJY7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_fWSYsxFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MakdcQZL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MakdcQZL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_6huIPzbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MakdcQZL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_MakdcQZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CINtlk0z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_DiWzRs1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CKyGiC3x_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_m38XO1wr, 0, m, &cIf_m38XO1wr_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_m38XO1wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pUqd2FLM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_icNAbTAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LINsG111_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_2C6CjzHF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_2rOvqmUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KFSzc6E8, HV_BINOP_POW, 0, m, &cBinop_KFSzc6E8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KFSzc6E8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mb2tahmH, 0, m, &cIf_mb2tahmH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2XhCQPaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9CMTlxa9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1gUBSpM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xkW2iDGu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OEUss8ei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_icNAbTAH, 0, m, &cIf_icNAbTAH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xkW2iDGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_icNAbTAH, 1, m, &cIf_icNAbTAH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2C6CjzHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_2XhCQPaW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LINsG111_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mb2tahmH, 0, m, &cIf_mb2tahmH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9CMTlxa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KFSzc6E8, HV_BINOP_POW, 1, m, &cBinop_KFSzc6E8_sendMessage);
  cMsg_2rOvqmUH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_mb2tahmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_VEsORcS7, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_CKyGiC3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m38XO1wr, 1, m, &cIf_m38XO1wr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pUqd2FLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AN9fS4SC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_AN9fS4SC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_m2jGGst0, HV_BINOP_EQ, 1, m, &cBinop_m2jGGst0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NRhxmnwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YeZenIud, HV_BINOP_ADD, 0, m, &cBinop_YeZenIud_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YeZenIud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1gUBSpM2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OEUss8ei_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AN9fS4SC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mb2tahmH, 1, m, &cIf_mb2tahmH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m2jGGst0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X4rojxWu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_X4rojxWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VEsORcS7, m);
}

void Heavy_WSTD_DL3Y::cCast_s8x4OrCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YeZenIud, HV_BINOP_ADD, 1, m, &cBinop_YeZenIud_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AN9fS4SC, HV_BINOP_GREATER_THAN, 0, m, &cBinop_AN9fS4SC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_m2jGGst0, HV_BINOP_EQ, 0, m, &cBinop_m2jGGst0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tltcF8K9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DiWzRs1T, 0, m, &cVar_DiWzRs1T_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_90ociHKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NRhxmnwF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_W2ZIFUYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wXBWpRqJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kJbaI1iq, 0, m, &cIf_kJbaI1iq_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_kJbaI1iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qlngSfLI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_CDibWM64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7uJCfbrX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_vPEcIYyn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_KQjLCpG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vqDlE6J1, HV_BINOP_POW, 0, m, &cBinop_vqDlE6J1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vqDlE6J1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zqW37sQj, 0, m, &cIf_zqW37sQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JQ3O5wKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Vv382CK0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QDoAICJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CDibWM64, 0, m, &cIf_CDibWM64_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nl3VOHD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_o18hCPlC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o18hCPlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CDibWM64, 1, m, &cIf_CDibWM64_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vPEcIYyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_JQ3O5wKd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7uJCfbrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zqW37sQj, 0, m, &cIf_zqW37sQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vv382CK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vqDlE6J1, HV_BINOP_POW, 1, m, &cBinop_vqDlE6J1_sendMessage);
  cMsg_KQjLCpG8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_zqW37sQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iIb3vuWJ_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xBrj4vwX_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6JCLckFO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_wXBWpRqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kJbaI1iq, 1, m, &cIf_kJbaI1iq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qlngSfLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zpLf0PT0, HV_BINOP_GREATER_THAN, 1, m, &cBinop_zpLf0PT0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1jmMjGkm, HV_BINOP_EQ, 1, m, &cBinop_1jmMjGkm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_snBngOuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RV0QRpFp, HV_BINOP_ADD, 0, m, &cBinop_RV0QRpFp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RV0QRpFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nl3VOHD5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QDoAICJG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zpLf0PT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zqW37sQj, 1, m, &cIf_zqW37sQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1jmMjGkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5adUG5iF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_5adUG5iF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iIb3vuWJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xBrj4vwX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6JCLckFO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7KvgGq4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W2ZIFUYj, 0, m, &cVar_W2ZIFUYj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aWMZ0HA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_snBngOuc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dJtIUnrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RV0QRpFp, HV_BINOP_ADD, 1, m, &cBinop_RV0QRpFp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zpLf0PT0, HV_BINOP_GREATER_THAN, 0, m, &cBinop_zpLf0PT0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1jmMjGkm, HV_BINOP_EQ, 0, m, &cBinop_1jmMjGkm_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1dwSsGsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DGqGj3Oq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_L80H0yCc, 0, m, &cIf_L80H0yCc_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_L80H0yCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TFVNLuhL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_fx8YHlo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_BCNUyYrL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Mv2cemqR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_sprPVXai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aKnLGFp3, HV_BINOP_POW, 0, m, &cBinop_aKnLGFp3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aKnLGFp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wULIEPXw, 0, m, &cIf_wULIEPXw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SxJr8EzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_jUbJu1YL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gxUkgx3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MVRxxJbj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sOLeykPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fx8YHlo5, 0, m, &cIf_fx8YHlo5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MVRxxJbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fx8YHlo5, 1, m, &cIf_fx8YHlo5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Mv2cemqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_SxJr8EzL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BCNUyYrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_wULIEPXw, 0, m, &cIf_wULIEPXw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jUbJu1YL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aKnLGFp3, HV_BINOP_POW, 1, m, &cBinop_aKnLGFp3_sendMessage);
  cMsg_sprPVXai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_wULIEPXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_8vgK8q2A, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_DGqGj3Oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L80H0yCc, 1, m, &cIf_L80H0yCc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TFVNLuhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YE8UmCO3, HV_BINOP_GREATER_THAN, 1, m, &cBinop_YE8UmCO3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TZp3Fvbu, HV_BINOP_EQ, 1, m, &cBinop_TZp3Fvbu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rFGRrnmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5cVzkFCs, HV_BINOP_ADD, 0, m, &cBinop_5cVzkFCs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5cVzkFCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gxUkgx3k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sOLeykPM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YE8UmCO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wULIEPXw, 1, m, &cIf_wULIEPXw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TZp3Fvbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z4XMRnpG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Z4XMRnpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8vgK8q2A, m);
}

void Heavy_WSTD_DL3Y::cCast_V79jwkcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1dwSsGsm, 0, m, &cVar_1dwSsGsm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5q8p9yaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rFGRrnmj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NRWYXJgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5cVzkFCs, HV_BINOP_ADD, 1, m, &cBinop_5cVzkFCs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YE8UmCO3, HV_BINOP_GREATER_THAN, 0, m, &cBinop_YE8UmCO3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TZp3Fvbu, HV_BINOP_EQ, 0, m, &cBinop_TZp3Fvbu_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_U9KRiWjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_SOvOdmT7, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_BK3dtbkb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2hQy56Vf, 0, m, &cSlice_2hQy56Vf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2F0J1XOA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_2hQy56Vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PZP5KCNF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PZP5KCNF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_BWDko8m5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PZP5KCNF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PZP5KCNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hDGyZFGR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2F0J1XOA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zH3PRMmH, 0, m, &cSlice_zH3PRMmH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LU2BL4hh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_zH3PRMmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_q30h1IR5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_q30h1IR5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_xVTILxzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q30h1IR5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_q30h1IR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2cHyo2C8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_l2MlAJY7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nQmTUydO, 0, m, &cSlice_nQmTUydO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7UMFHpog_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_nQmTUydO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qWF8HLU8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qWF8HLU8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_3zntZfTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qWF8HLU8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qWF8HLU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yx5UxUba_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7UMFHpog_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_L4ouSIOF, 0, m, &cSlice_L4ouSIOF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_L4ouSIOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1DoUv9dl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1DoUv9dl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_emk0YOaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1DoUv9dl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_1DoUv9dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VX77yWG1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_9zdDCQvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5C7ihpwN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IOOs6Vb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5Lu03wVh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kno5t53D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1465mirn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_q1VLJhdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BjT1Dq6i, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_o00K6xe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_A9mgmbG8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fGhKJRt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Hxo105fn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Hxo105fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oRgn8ZSt, HV_BINOP_DIVIDE, 1, m, &cBinop_oRgn8ZSt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rHIMpn9k_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_M498qvac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_eZPIAc0l_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_08OUBESN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_M498qvac_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eZPIAc0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oRgn8ZSt, HV_BINOP_DIVIDE, 0, m, &cBinop_oRgn8ZSt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rHIMpn9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_08OUBESN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oRgn8ZSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlPccD6X, HV_BINOP_MULTIPLY, 1, m, &cBinop_dlPccD6X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dlPccD6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UliL4uJT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZMTmF0kK_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_fuckqwxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iFwfQWjY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_ICDGih6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ItkY3oI5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xrKQqbsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_CUaXhdI8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CUaXhdI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlPccD6X, HV_BINOP_MULTIPLY, 0, m, &cBinop_dlPccD6X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_64g8pBZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_msDW7PMq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_msDW7PMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ixhlge5q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_X6xR35zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VBNeJocK, 1, m, &cVar_VBNeJocK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VBNeJocK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_omozx6J4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QUBVuPf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WgY5rNhW, HV_BINOP_MULTIPLY, 1, m, &cBinop_WgY5rNhW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cX2uTuGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QUBVuPf6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6yV5X5aY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_L2y7dpx3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L2y7dpx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lBQZ8mmp, HV_BINOP_MULTIPLY, 1, m, &cBinop_lBQZ8mmp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ySBntWSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rdQvgjGO, HV_BINOP_MULTIPLY, 1, m, &cBinop_rdQvgjGO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ByWluOmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ySBntWSp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tBmaS0cM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ab4ERtBd, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ab4ERtBd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bLO3wOEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uyYwFNiu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uyYwFNiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_shQU6DxH, HV_BINOP_MULTIPLY, 1, m, &cBinop_shQU6DxH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_srNpwRyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GRNo8uRM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_xrKQqbsJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R5PMv5BS_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Y1muCR9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_64g8pBZ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZMTmF0kK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ICDGih6k_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UliL4uJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fuckqwxL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_iFwfQWjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NHvwYyeI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ItkY3oI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MHgaDBcG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_hriOJEet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5BD8Iqif_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Ixhlge5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fEhWCqov_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fEhWCqov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nfDeghfY, HV_BINOP_MULTIPLY, 1, m, &cBinop_nfDeghfY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nfDeghfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MfDprAa5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MfDprAa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hriOJEet_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_omozx6J4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V56gPL0A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V56gPL0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xGkWcRgT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8FhM06UN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l9dE21FW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0CAcop94_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nZeBgiKV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vSRCRpsb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WgY5rNhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9zdDCQvd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lBQZ8mmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IOOs6Vb1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rdQvgjGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kno5t53D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ab4ERtBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q1VLJhdF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_shQU6DxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o00K6xe2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_BFapjscX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_srNpwRyP, 0, m, &cVar_srNpwRyP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rUwIsP8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y1muCR9P, 1, m, &cVar_Y1muCR9P_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l9dE21FW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ab4ERtBd, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ab4ERtBd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nZeBgiKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lBQZ8mmp, HV_BINOP_MULTIPLY, 0, m, &cBinop_lBQZ8mmp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xGkWcRgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_8FhM06UN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_shQU6DxH, HV_BINOP_MULTIPLY, 0, m, &cBinop_shQU6DxH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vSRCRpsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WgY5rNhW, HV_BINOP_MULTIPLY, 0, m, &cBinop_WgY5rNhW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0CAcop94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rdQvgjGO, HV_BINOP_MULTIPLY, 0, m, &cBinop_rdQvgjGO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GRNo8uRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y1muCR9P, 0, m, &cVar_Y1muCR9P_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_R5PMv5BS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VBNeJocK, 0, m, &cVar_VBNeJocK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_j9xCZQWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0dLIN6A7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TXL741AC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PHeP7A0y, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_11M4wmBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hafV42BE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gZpmI65i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0SpwpJPL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_iXVY1R86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IsvdxksZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IsvdxksZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cGGZ7mdo, HV_BINOP_DIVIDE, 1, m, &cBinop_cGGZ7mdo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DUcqsn8C_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_dvrAQKaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_JyT0o6OZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IREbOpQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_dvrAQKaf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JyT0o6OZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cGGZ7mdo, HV_BINOP_DIVIDE, 0, m, &cBinop_cGGZ7mdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DUcqsn8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IREbOpQL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cGGZ7mdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhQbBnCj, HV_BINOP_MULTIPLY, 1, m, &cBinop_dhQbBnCj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dhQbBnCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CWEwJYPQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uCqXWvWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_cchXBLDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wEe4HNHR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_NxuzPSWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B3KDbIdy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WlTDSvuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_fXlymWpM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fXlymWpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhQbBnCj, HV_BINOP_MULTIPLY, 0, m, &cBinop_dhQbBnCj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OVVSTDik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_J6wpsOjz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J6wpsOjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_900TDREo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ewo0hBnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kgpCsivV, HV_BINOP_MULTIPLY, 1, m, &cBinop_kgpCsivV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KDoagzq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mWQos0iy, 1, m, &cVar_mWQos0iy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l0xpAXSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sxMzCk0Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_sxMzCk0Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wQzsSJDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Eok3dzD8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Eok3dzD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obVxIYKA, HV_BINOP_MULTIPLY, 1, m, &cBinop_obVxIYKA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mWQos0iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DqdRBlwn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_dLfxWxiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p7m3ed2G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_WlTDSvuX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5nC8ogB_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Kz4Q48ZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_OVVSTDik_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CWEwJYPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_cchXBLDZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uCqXWvWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_NxuzPSWF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_wEe4HNHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SxXu2IbT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_B3KDbIdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FfC7h50X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_gOt3f5fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V3Bjsuj1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_900TDREo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uY5LmVLE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uY5LmVLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UL93fpcB, HV_BINOP_MULTIPLY, 1, m, &cBinop_UL93fpcB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UL93fpcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3n8M72eX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3n8M72eX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gOt3f5fe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_DqdRBlwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lmiCRmV3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lmiCRmV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lV01qjkN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wM6CipSU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g9iJ4Mre_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J5I8Rb0s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JMhqUXOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j9xCZQWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kgpCsivV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TXL741AC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sxMzCk0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_11M4wmBR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_obVxIYKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gZpmI65i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zw1bOPqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dLfxWxiC, 0, m, &cVar_dLfxWxiC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_O8IsXSB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kz4Q48ZQ, 1, m, &cVar_Kz4Q48ZQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c5nC8ogB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mWQos0iy, 0, m, &cVar_mWQos0iy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_p7m3ed2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kz4Q48ZQ, 0, m, &cVar_Kz4Q48ZQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_g9iJ4Mre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kgpCsivV, HV_BINOP_MULTIPLY, 0, m, &cBinop_kgpCsivV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lV01qjkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obVxIYKA, HV_BINOP_MULTIPLY, 0, m, &cBinop_obVxIYKA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wM6CipSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sxMzCk0Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_sxMzCk0Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_J5I8Rb0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JMhqUXOO, HV_BINOP_MULTIPLY, 0, m, &cBinop_JMhqUXOO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zMbU8zSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SYcW4oJO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wBmDiwEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ODGBWXBW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UCCIUAG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BtsKVKf3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fsbbZFQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r6h6C8In, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_KH88LKMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NP6lxrdh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6vgHsrfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RxCGdZYK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RxCGdZYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3GqE3Qoj, HV_BINOP_DIVIDE, 1, m, &cBinop_3GqE3Qoj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pbd3JfXd_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_BiXFETG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_XyRo5ipQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3ssbn4qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_BiXFETG9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XyRo5ipQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3GqE3Qoj, HV_BINOP_DIVIDE, 0, m, &cBinop_3GqE3Qoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pbd3JfXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ssbn4qr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3GqE3Qoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ctTeoJAt, HV_BINOP_MULTIPLY, 1, m, &cBinop_ctTeoJAt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ctTeoJAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rg7d9mYN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2WlAZcW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_uX80nAiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ft8DHtWl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_AKGUth9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LxuurZuf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_anyYML3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_tOT6sqJn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tOT6sqJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ctTeoJAt, HV_BINOP_MULTIPLY, 0, m, &cBinop_ctTeoJAt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Mk3taToG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_zPzyc3lI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zPzyc3lI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KuiyfRd5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lqIVv36o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_phaQ1BsN, HV_BINOP_MULTIPLY, 1, m, &cBinop_phaQ1BsN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DDtCEYlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5BgpNk9u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5BgpNk9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lqIVv36o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7MQZpctI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Dn0LsEXD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Dn0LsEXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N152sTGF, HV_BINOP_MULTIPLY, 1, m, &cBinop_N152sTGF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p6zPX3hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3cYqtMnE, HV_BINOP_MULTIPLY, 1, m, &cBinop_3cYqtMnE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8eiaOLl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7jm4lkQA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7jm4lkQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_p6zPX3hq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gjlbKlNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kwXzIFel, 1, m, &cVar_kwXzIFel_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aCqMDLbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NrviormF, HV_BINOP_MULTIPLY, 1, m, &cBinop_NrviormF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xmYwHype_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1y0jfILm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1y0jfILm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tByyuR4T, HV_BINOP_MULTIPLY, 1, m, &cBinop_tByyuR4T_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_kwXzIFel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_95PzlYaf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_8G1o3Ixx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0NwqBigw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_anyYML3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UoPdV75W_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_NdALQG5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Mk3taToG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2WlAZcW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_AKGUth9w_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rg7d9mYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_uX80nAiy_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_ft8DHtWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XCZrvY9F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_LxuurZuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bu4iSiFY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_dESPZdJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_afWdFgXd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KuiyfRd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QRcqgThX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QRcqgThX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K1Piue1l, HV_BINOP_MULTIPLY, 1, m, &cBinop_K1Piue1l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K1Piue1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YRwKpkfC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YRwKpkfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dESPZdJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_95PzlYaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9WP2VApr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9WP2VApr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v2nnpF2C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jpz9RLfN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Fj7dpM9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b7axy2AU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DmE1XdpE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bqa6ifO0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_phaQ1BsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zMbU8zSF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_N152sTGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wBmDiwEA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3cYqtMnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UCCIUAG6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NrviormF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fsbbZFQE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tByyuR4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KH88LKMr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zmphr9Ju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8G1o3Ixx, 0, m, &cVar_8G1o3Ixx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xtE5tNwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NdALQG5o, 1, m, &cVar_NdALQG5o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DmE1XdpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N152sTGF, HV_BINOP_MULTIPLY, 0, m, &cBinop_N152sTGF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Bqa6ifO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_phaQ1BsN, HV_BINOP_MULTIPLY, 0, m, &cBinop_phaQ1BsN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jpz9RLfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tByyuR4T, HV_BINOP_MULTIPLY, 0, m, &cBinop_tByyuR4T_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7Fj7dpM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NrviormF, HV_BINOP_MULTIPLY, 0, m, &cBinop_NrviormF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v2nnpF2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_b7axy2AU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3cYqtMnE, HV_BINOP_MULTIPLY, 0, m, &cBinop_3cYqtMnE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0NwqBigw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NdALQG5o, 0, m, &cVar_NdALQG5o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UoPdV75W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kwXzIFel, 0, m, &cVar_kwXzIFel_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iIb3vuWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U9KRiWjC, 1, m, &cIf_U9KRiWjC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0Gwn0JUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SOvOdmT7, m);
}

void Heavy_WSTD_DL3Y::cBinop_xBrj4vwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Gwn0JUG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6JCLckFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U9KRiWjC, 0, m, &cIf_U9KRiWjC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ut0MAWD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhDVO8Tt, HV_BINOP_DIVIDE, 0, m, &cBinop_QhDVO8Tt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CO65YgiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7rp1uS9Q, HV_BINOP_DIVIDE, 1, m, &cBinop_7rp1uS9Q_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhDVO8Tt, HV_BINOP_DIVIDE, 1, m, &cBinop_QhDVO8Tt_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_HvDSSYqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OKfhpvGB, HV_BINOP_DIVIDE, 0, m, &cBinop_OKfhpvGB_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_KwAHHsUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OKfhpvGB, HV_BINOP_DIVIDE, 1, m, &cBinop_OKfhpvGB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8H3YnNiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CO65YgiW, 0, m, &cVar_CO65YgiW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wLYKepsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7rp1uS9Q, HV_BINOP_DIVIDE, 0, m, &cBinop_7rp1uS9Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JHtWRlMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ut0MAWD1, 0, m, &cVar_Ut0MAWD1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7rp1uS9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_HvDSSYqK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QhDVO8Tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_KwAHHsUJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OKfhpvGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_0gqRp2aD_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_RBbspOkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_Xh6skPiw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i0R7wzpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_ullKGNFt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0gqRp2aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_i0R7wzpE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ullKGNFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_RBbspOkJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xh6skPiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JHZxZ2hR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_EkcRcnNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pVs4hn0x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_kW333plv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pul3hgjL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_65RMxHSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EqtU0Q3I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CAq5BeJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hXyq3chg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_sIy2ju4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7gJ3fabU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JhEhH5rO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GY8Ft1O8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_GuTTrRUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R4jJ11sz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_DdpKo0v7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WJcZqZ5e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_y6UKHuvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5V1aihon_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_gTOE3GeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZczpVTVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Cg6BIfZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TdBj9axc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6Lt3xio0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xjk2Rtj2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_GW48opJC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_o8pOWhFt, 0, m, &cSlice_o8pOWhFt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_o8pOWhFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ufd00agw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ufd00agw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_UbChdC6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ufd00agw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Ufd00agw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6RiIExtb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zHPCiEr1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3makVIlX, 0, m, &cSlice_3makVIlX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JkCIKq6F_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3makVIlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AUzZzIRN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AUzZzIRN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_R0YmKN59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AUzZzIRN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_AUzZzIRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_u88eovKD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KvWQBEGI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_d1unY20j, 0, m, &cSlice_d1unY20j_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GW48opJC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_d1unY20j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XsAWXWTK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XsAWXWTK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RXhXU9dS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XsAWXWTK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_XsAWXWTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CkCQ85nl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OKbGjADI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_98XT0cHw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_98XT0cHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ZufI61An_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_e1Zb1c1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l6zrNnDq_sendMessage(_c, 0, m);
  cMsg_LaSfe3zb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_5JD7yl7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gpg5cifK_sendMessage(_c, 0, m);
  cMsg_GXc2gzJt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZufI61An_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pCYrZ6KM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pCYrZ6KM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n70jXn5i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UROmlVhN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_n70jXn5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AyRO9pwi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UROmlVhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tE3GP8Tm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AyRO9pwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PSkhlAO7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tE3GP8Tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_n2sR4IB9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n2sR4IB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ipIgG5fp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PSkhlAO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_e1Zb1c1f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ipIgG5fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_5JD7yl7U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gi0Oe7sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DkYLOJJC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DkYLOJJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_9yM1pi2b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9yM1pi2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_z8Ywqin5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z8Ywqin5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dZYCyfdb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dRuNjy7D_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dRuNjy7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gnJxxQeA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dZYCyfdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bLPfn3LY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bLPfn3LY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Hd1cf9ou_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gnJxxQeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7Vz2JC7a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Vz2JC7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5ETHCkdy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5ETHCkdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HFw0Aphm_sendMessage(_c, 0, m);
  cMsg_yQApD2za_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Hd1cf9ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H0T7PRz3_sendMessage(_c, 0, m);
  cMsg_vDOlsxHk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZgCq8FCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_uyNxpbPt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uyNxpbPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Csp1wBo8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RvWpXbKD_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_eylp7s1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_nEET1P7u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_C4gWZ4n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_593pgRND_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_593pgRND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1yevOqA9, HV_BINOP_DIVIDE, 1, m, &cBinop_1yevOqA9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Csp1wBo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2u9tA0ie_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2u9tA0ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1AC8qUtn, m);
}

void Heavy_WSTD_DL3Y::cMsg_uZ6C1kBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SjIlSsCR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SjIlSsCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZgCq8FCy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RvWpXbKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_otbMVUga, m);
}

void Heavy_WSTD_DL3Y::cBinop_nEET1P7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_5PfLhRF8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5PfLhRF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1yevOqA9, HV_BINOP_DIVIDE, 0, m, &cBinop_1yevOqA9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1yevOqA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uZ6C1kBf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HLaqrpeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_PImDEjtn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PImDEjtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TFrLAkBB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_olCqVqgr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_D8Pcv1aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_1kKXqj1L_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DOs7XovF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_npiXpqts_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_npiXpqts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ufuJlv9N, HV_BINOP_DIVIDE, 1, m, &cBinop_ufuJlv9N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TFrLAkBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Yyf0drXx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Yyf0drXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_K8wUAsoQ, m);
}

void Heavy_WSTD_DL3Y::cMsg_Cq75PjTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mcyv20Rc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mcyv20Rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_HLaqrpeh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_olCqVqgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2beDsilW, m);
}

void Heavy_WSTD_DL3Y::cBinop_1kKXqj1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_ai813Ndc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ai813Ndc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ufuJlv9N, HV_BINOP_DIVIDE, 0, m, &cBinop_ufuJlv9N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ufuJlv9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cq75PjTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_d19RT6Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kT0gAl9r, HV_BINOP_MULTIPLY, 0, m, &cBinop_kT0gAl9r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J7bAmXff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XXLEX8r7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XXLEX8r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IA4IlL0j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kT0gAl9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CC8fLqRd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2dc1V4Qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kT0gAl9r, HV_BINOP_MULTIPLY, 1, m, &cBinop_kT0gAl9r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IA4IlL0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2dc1V4Qq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CC8fLqRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_s5iAvT4y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s5iAvT4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nyjzrmNR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6gj6aMYw, m);
}

void Heavy_WSTD_DL3Y::cBinop_nyjzrmNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gMikaZQe, m);
}

void Heavy_WSTD_DL3Y::cVar_bx89yx6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iWLoha5s, HV_BINOP_MULTIPLY, 0, m, &cBinop_iWLoha5s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DVSvHOFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cmGSgA78_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cmGSgA78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aHgzpJ1C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iWLoha5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xd4dTvUt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yj1b4sEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iWLoha5s, HV_BINOP_MULTIPLY, 1, m, &cBinop_iWLoha5s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aHgzpJ1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yj1b4sEp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xd4dTvUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_JkUQT7DQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JkUQT7DQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ADaeaB0j_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bRmQVy3n, m);
}

void Heavy_WSTD_DL3Y::cBinop_ADaeaB0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ipL62r7u, m);
}

void Heavy_WSTD_DL3Y::sEnv_nANzx3UD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EpFaQ4cz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U8uTH1ui_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_oBgtKT0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HOmwxfHT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_st2me756_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_uSsL13vt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AAUhKhNC, HV_BINOP_POW, 0, m, &cBinop_AAUhKhNC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AAUhKhNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tLSWHvoj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZNGpn7nS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fMSgY0S1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EpFaQ4cz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_F3HafFym_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U8uTH1ui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oBgtKT0R, 0, m, &cIf_oBgtKT0R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F3HafFym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oBgtKT0R, 1, m, &cIf_oBgtKT0R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_st2me756_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZNGpn7nS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HOmwxfHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_tLSWHvoj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fMSgY0S1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AAUhKhNC, HV_BINOP_POW, 1, m, &cBinop_AAUhKhNC_sendMessage);
  cMsg_uSsL13vt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RwkghXtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uGFiwKvM, HV_BINOP_MULTIPLY, 0, m, &cBinop_uGFiwKvM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FOwcVR2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8AO3qO3D_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_8AO3qO3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aKKvZke4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_uGFiwKvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_HLePa1O1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XxsVaRab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uGFiwKvM, HV_BINOP_MULTIPLY, 1, m, &cBinop_uGFiwKvM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aKKvZke4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XxsVaRab_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HLePa1O1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8Yk659Hm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8Yk659Hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IlBrOUjr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VUO83LzB, m);
}

void Heavy_WSTD_DL3Y::cBinop_IlBrOUjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_YkZDzIKr, m);
}

void Heavy_WSTD_DL3Y::cMsg_tLSWHvoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Qohsl3Xu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qohsl3Xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tLsFDF0J, m);
}

void Heavy_WSTD_DL3Y::sEnv_rZJppz6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oz8FxXp3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eeByaGKa_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_WgnxmcVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MwUkLqwZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_90AvYehE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_PJ1lNgzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lt0tKNu7, HV_BINOP_POW, 0, m, &cBinop_Lt0tKNu7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lt0tKNu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W8WPAa3j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OH4ltScs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fVfmIUJo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oz8FxXp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IC4OOttb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eeByaGKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WgnxmcVh, 0, m, &cIf_WgnxmcVh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IC4OOttb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WgnxmcVh, 1, m, &cIf_WgnxmcVh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_90AvYehE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_OH4ltScs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MwUkLqwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_W8WPAa3j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fVfmIUJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lt0tKNu7, HV_BINOP_POW, 1, m, &cBinop_Lt0tKNu7_sendMessage);
  cMsg_PJ1lNgzw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LTX87KUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Em8udKNl, HV_BINOP_MULTIPLY, 0, m, &cBinop_Em8udKNl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OcAgL7Sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xsT0PT3e_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xsT0PT3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mlg11Rqm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Em8udKNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9ow2SGu2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uDeTyAOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Em8udKNl, HV_BINOP_MULTIPLY, 1, m, &cBinop_Em8udKNl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mlg11Rqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uDeTyAOx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ow2SGu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qLwkiQ0P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qLwkiQ0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ucr0UWih_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bANcYv5C, m);
}

void Heavy_WSTD_DL3Y::cBinop_ucr0UWih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_y8Gq0zGl, m);
}

void Heavy_WSTD_DL3Y::cMsg_W8WPAa3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_R7E2ExLa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R7E2ExLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zf4W2DkK, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_JkCIKq6F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ReYnj3Hg, 0, m, &cSlice_ReYnj3Hg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KvWQBEGI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ReYnj3Hg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ncJxT27a_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ncJxT27a_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_9uf78VUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ncJxT27a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ncJxT27a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qr36bNun_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_XUPh1a1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nC7qIixI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_nC7qIixI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_KEZkUQXi_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_VJ0TRFMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VJ0TRFMH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LE2YWA1s, 0, m, &cDelay_LE2YWA1s_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VJ0TRFMH, 0, m, &cDelay_VJ0TRFMH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2GitFjeT, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_LE2YWA1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LE2YWA1s, m);
  cMsg_1EnrKUkc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XZLFx5nD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_4DLOCQWm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_6Uhd2Gr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P2TAf0Sn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_bfMHjUIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pO4Zc6Ge_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VJ0TRFMH, 2, m, &cDelay_VJ0TRFMH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qIMcRQhd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P2TAf0Sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bfMHjUIg, 0, m, &hTable_bfMHjUIg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KEZkUQXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_6Uhd2Gr8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1EnrKUkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bfMHjUIg, 0, m, &hTable_bfMHjUIg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qIMcRQhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VJ0TRFMH, 0, m, &cDelay_VJ0TRFMH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pO4Zc6Ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_LE2YWA1s, 2, m, &cDelay_LE2YWA1s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4DLOCQWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2GitFjeT, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_FvjB1YIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ygfC7mHK, HV_BINOP_SUBTRACT, 0, m, &cBinop_ygfC7mHK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_g4l6vCSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MS0cEWAw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MS0cEWAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6pmDHjAi_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_EBLqxK4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WCkjNmy8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_4zYNvNs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4zYNvNs2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7B98ZSaW, 0, m, &cDelay_7B98ZSaW_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BVxw12tT, 0, m, &sTabread_BVxw12tT_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_7B98ZSaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7B98ZSaW, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BVxw12tT, 0, m, &sTabread_BVxw12tT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7B98ZSaW, 0, m, &cDelay_7B98ZSaW_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_BVxw12tT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hF7oZ2YH, HV_BINOP_SUBTRACT, 0, m, &cBinop_hF7oZ2YH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_h8aTTjn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6RLoQu4t, HV_BINOP_MAX, 0, m, &cBinop_6RLoQu4t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6pmDHjAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h8aTTjn9, HV_BINOP_MULTIPLY, 0, m, &cBinop_h8aTTjn9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ygfC7mHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RPE1ToL8_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BVxw12tT, 0, m, &sTabread_BVxw12tT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dWcdaUg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_3hVRF0er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hF7oZ2YH, HV_BINOP_SUBTRACT, 1, m, &cBinop_hF7oZ2YH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7B98ZSaW, 2, m, &cDelay_7B98ZSaW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WCkjNmy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3hVRF0er_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RPE1ToL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4zYNvNs2, 0, m, &cDelay_4zYNvNs2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7B98ZSaW, 0, m, &cDelay_7B98ZSaW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_54HOC8yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_6RLoQu4t, HV_BINOP_MAX, 1, m, &cBinop_6RLoQu4t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6RLoQu4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ygfC7mHK, HV_BINOP_SUBTRACT, 1, m, &cBinop_ygfC7mHK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dWcdaUg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4zYNvNs2, 0, m, &cDelay_4zYNvNs2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pQ6CQNz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4zYNvNs2, 2, m, &cDelay_4zYNvNs2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hF7oZ2YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pQ6CQNz0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xcLvft77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EBLqxK4p, 0, m, &cVar_EBLqxK4p_sendMessage);
  cMsg_g4l6vCSs_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FvjB1YIG, 0, m, &cTabhead_FvjB1YIG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_y3K88II9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hpNtyqpe_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hpNtyqpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IgOSosrg_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_eFPPzsHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eFPPzsHv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IyyFLTMY, 0, m, &cDelay_IyyFLTMY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eFPPzsHv, 0, m, &cDelay_eFPPzsHv_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0UsS9AuZ, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_IyyFLTMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IyyFLTMY, m);
  cMsg_W1YT8YYB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_9X4Z5lQn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_taDK9Tg2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_VwtUbVkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DFDhxJi9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_TKQiRNT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OzF3XqvF_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eFPPzsHv, 2, m, &cDelay_eFPPzsHv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pqMauA8R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DFDhxJi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TKQiRNT0, 0, m, &hTable_TKQiRNT0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IgOSosrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_VwtUbVkL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W1YT8YYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TKQiRNT0, 0, m, &hTable_TKQiRNT0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pqMauA8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eFPPzsHv, 0, m, &cDelay_eFPPzsHv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OzF3XqvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_IyyFLTMY, 2, m, &cDelay_IyyFLTMY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_taDK9Tg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0UsS9AuZ, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_7dZD0CDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AwBRlMBT, HV_BINOP_SUBTRACT, 0, m, &cBinop_AwBRlMBT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NdlHywCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VyJyxHrW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_VyJyxHrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2WbzvWU1_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_z6BltCi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MdoWSnLD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_pQaDOhQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pQaDOhQa, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FudEqlS7, 0, m, &cDelay_FudEqlS7_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_alXsi6o1, 0, m, &sTabread_alXsi6o1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_FudEqlS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FudEqlS7, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_alXsi6o1, 0, m, &sTabread_alXsi6o1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FudEqlS7, 0, m, &cDelay_FudEqlS7_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_alXsi6o1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_T6WFsfE5, HV_BINOP_SUBTRACT, 0, m, &cBinop_T6WFsfE5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_oISgB9C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U8briahB, HV_BINOP_MAX, 0, m, &cBinop_U8briahB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2WbzvWU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oISgB9C0, HV_BINOP_MULTIPLY, 0, m, &cBinop_oISgB9C0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AwBRlMBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4LMKrK4A_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_alXsi6o1, 0, m, &sTabread_alXsi6o1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gkobwwcf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_SBCCOSlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T6WFsfE5, HV_BINOP_SUBTRACT, 1, m, &cBinop_T6WFsfE5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FudEqlS7, 2, m, &cDelay_FudEqlS7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MdoWSnLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SBCCOSlz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4LMKrK4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pQaDOhQa, 0, m, &cDelay_pQaDOhQa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FudEqlS7, 0, m, &cDelay_FudEqlS7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Lej6rWrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_U8briahB, HV_BINOP_MAX, 1, m, &cBinop_U8briahB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U8briahB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AwBRlMBT, HV_BINOP_SUBTRACT, 1, m, &cBinop_AwBRlMBT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gkobwwcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pQaDOhQa, 0, m, &cDelay_pQaDOhQa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gga6ZGy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pQaDOhQa, 2, m, &cDelay_pQaDOhQa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T6WFsfE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Gga6ZGy4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EnuIafT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z6BltCi5, 0, m, &cVar_z6BltCi5_sendMessage);
  cMsg_NdlHywCd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7dZD0CDJ, 0, m, &cTabhead_7dZD0CDJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_l6zrNnDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CuuPYCt1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Gpg5cifK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IUL07AzI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GXc2gzJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mSzajeyt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LaSfe3zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qpYvlRBI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vDOlsxHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QFkLIRGx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HFw0Aphm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bK64IFnG, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_H0T7PRz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AFnoiCaE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yQApD2za_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s8X0LSXF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_PWDl07y1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qoweblUi, 0, m, &cSlice_qoweblUi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_qoweblUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_i2dqpunw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_i2dqpunw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_5x10O98S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i2dqpunw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_i2dqpunw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kFiPBE2y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iZvgxWHp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tKOT8YmH, 0, m, &cSlice_tKOT8YmH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lA1R7shF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_tKOT8YmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_g8l86FHl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_g8l86FHl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_E1WbXSlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g8l86FHl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_g8l86FHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MxpDbN6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_6PJu8vwJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M9xOOAf0, 0, m, &cSlice_M9xOOAf0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PWDl07y1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_M9xOOAf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NLKrRARG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NLKrRARG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_B8KOLt4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NLKrRARG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_NLKrRARG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jJq7P1hF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_p7qh7AgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_t7t7TTWo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t7t7TTWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_b7rLbTUY_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ccVKOrSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NOCdHDK4_sendMessage(_c, 0, m);
  cMsg_phnI1sOd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_PbMtEBYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WD0WQFK8_sendMessage(_c, 0, m);
  cMsg_O5jVwqX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_b7rLbTUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_X9F8BOo2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_X9F8BOo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aPp224NN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C9sSKq3r_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aPp224NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PdPESPlZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C9sSKq3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O8nGNYUg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PdPESPlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_E9tVPoaJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O8nGNYUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EVvxVYpB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EVvxVYpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RCvjd8Of_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E9tVPoaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_ccVKOrSD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RCvjd8Of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_PbMtEBYc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qJzFj7Zv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FBCw58yr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FBCw58yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_oVgDkcL8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oVgDkcL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2D7m4NHz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2D7m4NHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k9mgaejh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1GBLxWW6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1GBLxWW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7D3MNYPC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_k9mgaejh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ba5T5XEW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ba5T5XEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rOjUu1hf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7D3MNYPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kDXmB4Ba_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kDXmB4Ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_whQcr94Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_whQcr94Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JPgOaIYi_sendMessage(_c, 0, m);
  cMsg_8473DCdk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rOjUu1hf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XzGXEhah_sendMessage(_c, 0, m);
  cMsg_HvKMi5a5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CauQmV3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ifgzLfVr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ifgzLfVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VlPHU0Tr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nPboJyzr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gONEQ4Z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_nfbroDy2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hnsmUEju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oWF8UoSN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_oWF8UoSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mgLzcW0k, HV_BINOP_DIVIDE, 1, m, &cBinop_mgLzcW0k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VlPHU0Tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rKjzqi8k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rKjzqi8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7yW6cXFh, m);
}

void Heavy_WSTD_DL3Y::cMsg_2eeaPsCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d3taaL3L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d3taaL3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CauQmV3v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nPboJyzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4jc96OSn, m);
}

void Heavy_WSTD_DL3Y::cBinop_nfbroDy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_cm3c43hb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cm3c43hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mgLzcW0k, HV_BINOP_DIVIDE, 0, m, &cBinop_mgLzcW0k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mgLzcW0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2eeaPsCU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LsiaoLog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aj4lgmj5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aj4lgmj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1hMG6T51_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UciVW3rY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lcDExF26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_GXqhfx7Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jaBV8L9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MgwScJNp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MgwScJNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cZ8Sf3xH, HV_BINOP_DIVIDE, 1, m, &cBinop_cZ8Sf3xH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1hMG6T51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qKqG7aBv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qKqG7aBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_701SoLRi, m);
}

void Heavy_WSTD_DL3Y::cMsg_b97ea4Bt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DwkBMja6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DwkBMja6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LsiaoLog_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UciVW3rY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_09e4BcNL, m);
}

void Heavy_WSTD_DL3Y::cBinop_GXqhfx7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_7TdS2mqb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7TdS2mqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cZ8Sf3xH, HV_BINOP_DIVIDE, 0, m, &cBinop_cZ8Sf3xH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cZ8Sf3xH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b97ea4Bt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_QUbP8eKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_akA0xvz2, HV_BINOP_MULTIPLY, 0, m, &cBinop_akA0xvz2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dM17KubM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C5P5XeYr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_C5P5XeYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xrk7DuSy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_akA0xvz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_oLOHGzMI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aes35Hiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_akA0xvz2, HV_BINOP_MULTIPLY, 1, m, &cBinop_akA0xvz2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xrk7DuSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aes35Hiu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oLOHGzMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zDMhKpQe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zDMhKpQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_34PCFP5V_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gPX0lrb6, m);
}

void Heavy_WSTD_DL3Y::cBinop_34PCFP5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_r3VyMjQs, m);
}

void Heavy_WSTD_DL3Y::cVar_Dlj2t921_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q9QzGMIS, HV_BINOP_MULTIPLY, 0, m, &cBinop_q9QzGMIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_D7HLf3Ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_g9sOfIXN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_g9sOfIXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yp0mHyo7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_q9QzGMIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_okfsbyYU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_64PBZ472_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q9QzGMIS, HV_BINOP_MULTIPLY, 1, m, &cBinop_q9QzGMIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yp0mHyo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_64PBZ472_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_okfsbyYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_RlQd5w10_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RlQd5w10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dvdRSGGC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OBW5daYB, m);
}

void Heavy_WSTD_DL3Y::cBinop_dvdRSGGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CumH3e2n, m);
}

void Heavy_WSTD_DL3Y::sEnv_9eZh7Kzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_obsN2eDq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M7mHw0oR_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_2BaQD8r2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LJIKHSfP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_k6B4yV7h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Reo8zHJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AyOLF2zY, HV_BINOP_POW, 0, m, &cBinop_AyOLF2zY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AyOLF2zY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KR5iZJjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Vt8W9idM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cXzOwsdq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M7mHw0oR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2BaQD8r2, 0, m, &cIf_2BaQD8r2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_obsN2eDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KjayzXWV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KjayzXWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2BaQD8r2, 1, m, &cIf_2BaQD8r2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k6B4yV7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Vt8W9idM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LJIKHSfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_KR5iZJjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cXzOwsdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AyOLF2zY, HV_BINOP_POW, 1, m, &cBinop_AyOLF2zY_sendMessage);
  cMsg_Reo8zHJL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_kvHiK7dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eRSvF3fN, HV_BINOP_MULTIPLY, 0, m, &cBinop_eRSvF3fN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1WJz54nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hZO9e10O_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hZO9e10O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NebrkO0k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eRSvF3fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1LlPhwSN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7wJg70JI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eRSvF3fN, HV_BINOP_MULTIPLY, 1, m, &cBinop_eRSvF3fN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NebrkO0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7wJg70JI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1LlPhwSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ekd4GGuO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ekd4GGuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_C23LYHlq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_v4rq4hGI, m);
}

void Heavy_WSTD_DL3Y::cBinop_C23LYHlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tMaHM2sj, m);
}

void Heavy_WSTD_DL3Y::cMsg_KR5iZJjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4w8a4YaE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4w8a4YaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_m3CG3nev, m);
}

void Heavy_WSTD_DL3Y::sEnv_emHV5Ijb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ed4zsc0Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Z1586ar_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_VBBJzLsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_6AVYQjJM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_RHSbRWK3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_oBiZH988_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O8i5y7rb, HV_BINOP_POW, 0, m, &cBinop_O8i5y7rb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O8i5y7rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mp3xa2Of_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oWKgnOmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_4eutZ6xo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ed4zsc0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8OcBJiYu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0Z1586ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VBBJzLsa, 0, m, &cIf_VBBJzLsa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8OcBJiYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VBBJzLsa, 1, m, &cIf_VBBJzLsa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RHSbRWK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_oWKgnOmL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6AVYQjJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_mp3xa2Of_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4eutZ6xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O8i5y7rb, HV_BINOP_POW, 1, m, &cBinop_O8i5y7rb_sendMessage);
  cMsg_oBiZH988_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CPdJAFYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcKPFHCv, HV_BINOP_MULTIPLY, 0, m, &cBinop_gcKPFHCv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cByicscP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ObGUYHy6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ObGUYHy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_urFtvEIh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gcKPFHCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_B1xLTMxu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RGsaq8OS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcKPFHCv, HV_BINOP_MULTIPLY, 1, m, &cBinop_gcKPFHCv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_urFtvEIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RGsaq8OS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B1xLTMxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rebsvCiJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rebsvCiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7WLTx7dT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_orUszSzE, m);
}

void Heavy_WSTD_DL3Y::cBinop_7WLTx7dT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3mVDW4Oj, m);
}

void Heavy_WSTD_DL3Y::cMsg_mp3xa2Of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vYyh6fjn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vYyh6fjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OZ2fwsGT, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_lA1R7shF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gD9ksRAy, 0, m, &cSlice_gD9ksRAy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6PJu8vwJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_gD9ksRAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GoM0xFMP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GoM0xFMP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_XaU7Sz0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GoM0xFMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_GoM0xFMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xL7JRL9N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_k0Lp8x4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XRiaOTR8_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XRiaOTR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yCSdyIhd_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_p3IuRv3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p3IuRv3X, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_E1ZGKPUi, 0, m, &cDelay_E1ZGKPUi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p3IuRv3X, 0, m, &cDelay_p3IuRv3X_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bh0O2vyD, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_E1ZGKPUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E1ZGKPUi, m);
  cMsg_kUsUE3aj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Lc2OJuwU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ucVJQbkQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_pqi34odg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZdKF1GVZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_zi1xCbSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hcWygItf_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p3IuRv3X, 2, m, &cDelay_p3IuRv3X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PeXHgEl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZdKF1GVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zi1xCbSs, 0, m, &hTable_zi1xCbSs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yCSdyIhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_pqi34odg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kUsUE3aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zi1xCbSs, 0, m, &hTable_zi1xCbSs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PeXHgEl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p3IuRv3X, 0, m, &cDelay_p3IuRv3X_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hcWygItf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_E1ZGKPUi, 2, m, &cDelay_E1ZGKPUi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ucVJQbkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bh0O2vyD, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_T0sUfdBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1KnvCR1r, HV_BINOP_SUBTRACT, 0, m, &cBinop_1KnvCR1r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Pm6FZweL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ogfgW7qc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ogfgW7qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1b75Z54E_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_jcDNXssg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Si23VlI5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_EcHlhpWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EcHlhpWZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_10RMyi5M, 0, m, &cDelay_10RMyi5M_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8SeePa5K, 0, m, &sTabread_8SeePa5K_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_10RMyi5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_10RMyi5M, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8SeePa5K, 0, m, &sTabread_8SeePa5K_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_10RMyi5M, 0, m, &cDelay_10RMyi5M_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_8SeePa5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_QRR0d1cY, HV_BINOP_SUBTRACT, 0, m, &cBinop_QRR0d1cY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Wl25FzEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Gcr1I5O, HV_BINOP_MAX, 0, m, &cBinop_9Gcr1I5O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1b75Z54E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wl25FzEg, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wl25FzEg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1KnvCR1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b6tiscPl_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8SeePa5K, 0, m, &sTabread_8SeePa5K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iZY1sdPd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7h76XurN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QRR0d1cY, HV_BINOP_SUBTRACT, 1, m, &cBinop_QRR0d1cY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_10RMyi5M, 2, m, &cDelay_10RMyi5M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Si23VlI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7h76XurN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b6tiscPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EcHlhpWZ, 0, m, &cDelay_EcHlhpWZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_10RMyi5M, 0, m, &cDelay_10RMyi5M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wYaPrkRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Gcr1I5O, HV_BINOP_MAX, 1, m, &cBinop_9Gcr1I5O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9Gcr1I5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1KnvCR1r, HV_BINOP_SUBTRACT, 1, m, &cBinop_1KnvCR1r_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iZY1sdPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EcHlhpWZ, 0, m, &cDelay_EcHlhpWZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wS2NUGon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EcHlhpWZ, 2, m, &cDelay_EcHlhpWZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QRR0d1cY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wS2NUGon_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_scElCIDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jcDNXssg, 0, m, &cVar_jcDNXssg_sendMessage);
  cMsg_Pm6FZweL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_T0sUfdBM, 0, m, &cTabhead_T0sUfdBM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZCZlUCPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MAjMiBg1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MAjMiBg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UoQ6oZlC_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Qsnw62W7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Qsnw62W7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dG4wTvt9, 0, m, &cDelay_dG4wTvt9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qsnw62W7, 0, m, &cDelay_Qsnw62W7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9NIpHuaG, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_dG4wTvt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dG4wTvt9, m);
  cMsg_RGrZM9Hx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_22N5jnYF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mll6Cbhb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_NFAPqdXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tx6uSIXx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_pY6tUaMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YbgXc7VO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qsnw62W7, 2, m, &cDelay_Qsnw62W7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_17wqDMbK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tx6uSIXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_pY6tUaMi, 0, m, &hTable_pY6tUaMi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UoQ6oZlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_NFAPqdXU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RGrZM9Hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_pY6tUaMi, 0, m, &hTable_pY6tUaMi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_17wqDMbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qsnw62W7, 0, m, &cDelay_Qsnw62W7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YbgXc7VO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dG4wTvt9, 2, m, &cDelay_dG4wTvt9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mll6Cbhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9NIpHuaG, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_vKb9CMYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Bt0ep8P, HV_BINOP_SUBTRACT, 0, m, &cBinop_6Bt0ep8P_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DA3FjjoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3TcqJCZT_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_3TcqJCZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_sx2Q4FoJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_kugbDvZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_29wNCMhs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_yDDLRADH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yDDLRADH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_skokD83W, 0, m, &cDelay_skokD83W_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SLrxXmwY, 0, m, &sTabread_SLrxXmwY_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_skokD83W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_skokD83W, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SLrxXmwY, 0, m, &sTabread_SLrxXmwY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_skokD83W, 0, m, &cDelay_skokD83W_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_SLrxXmwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_qBR2SgUk, HV_BINOP_SUBTRACT, 0, m, &cBinop_qBR2SgUk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_GASsbMoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AdB5vU2X, HV_BINOP_MAX, 0, m, &cBinop_AdB5vU2X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sx2Q4FoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GASsbMoK, HV_BINOP_MULTIPLY, 0, m, &cBinop_GASsbMoK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6Bt0ep8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cPiPjIxg_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SLrxXmwY, 0, m, &sTabread_SLrxXmwY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7XolHugS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_963MqWEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qBR2SgUk, HV_BINOP_SUBTRACT, 1, m, &cBinop_qBR2SgUk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_skokD83W, 2, m, &cDelay_skokD83W_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_29wNCMhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_963MqWEr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cPiPjIxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yDDLRADH, 0, m, &cDelay_yDDLRADH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_skokD83W, 0, m, &cDelay_skokD83W_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pfRqi2Vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_AdB5vU2X, HV_BINOP_MAX, 1, m, &cBinop_AdB5vU2X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AdB5vU2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Bt0ep8P, HV_BINOP_SUBTRACT, 1, m, &cBinop_6Bt0ep8P_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7XolHugS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yDDLRADH, 0, m, &cDelay_yDDLRADH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_syxneMKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yDDLRADH, 2, m, &cDelay_yDDLRADH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qBR2SgUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_syxneMKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ywhcPMqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kugbDvZO, 0, m, &cVar_kugbDvZO_sendMessage);
  cMsg_DA3FjjoM_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vKb9CMYG, 0, m, &cTabhead_vKb9CMYG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NOCdHDK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8YO848gA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WD0WQFK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Of0RFGzc, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_O5jVwqX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ErK33IlO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_phnI1sOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VtbyeAnR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HvKMi5a5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_clWbRxZx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JPgOaIYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WvPylBzD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XzGXEhah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qmm3hGRE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8473DCdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3QUy4KzU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_l7JXmN3C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3Jn4nutr, 0, m, &cSlice_3Jn4nutr_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3Jn4nutr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_g9nZtg3m_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_g9nZtg3m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_bTOTsKue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g9nZtg3m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_g9nZtg3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uyPxIws0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_yxTYYvrW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gsusoO4k, 0, m, &cSlice_gsusoO4k_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aO6ZnNzM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_gsusoO4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KK82vpI7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KK82vpI7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_pO07ndbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KK82vpI7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KK82vpI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VtuDC3Jf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_PPnYrGfb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sH3G1s3a, 0, m, &cSlice_sH3G1s3a_sendMessage);
      break;
    }
    default: {
      cSwitchcase_l7JXmN3C_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_sH3G1s3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_60HHxj1R_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_60HHxj1R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_5sqogDZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_60HHxj1R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_60HHxj1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nIp0rFn8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_E2LKdOWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Upoaf6WT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Upoaf6WT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_rsaPRksz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_atmFjG3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a5itvoCm_sendMessage(_c, 0, m);
  cMsg_4OxFwXJc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_17kHb2WJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ObloUB6u_sendMessage(_c, 0, m);
  cMsg_amBechsy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rsaPRksz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hN66L8Ja_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hN66L8Ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_13l5OC2Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cBp6zyHt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cBp6zyHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9GhUvYaf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_13l5OC2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VlsdjLay_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VlsdjLay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_szkTe7XW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9GhUvYaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_z8xD5Oux_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z8xD5Oux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eZhImfSa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_szkTe7XW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_atmFjG3o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eZhImfSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_17kHb2WJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hXhEuifT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vf0JIfdf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vf0JIfdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_zAgzkHPp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zAgzkHPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1rSwSMmV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1rSwSMmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yAKxU6Uo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QAvkRwwC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yAKxU6Uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RYe2ycNR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QAvkRwwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CukDc9aQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RYe2ycNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Wzqfqy88_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CukDc9aQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zAPnJZBY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zAPnJZBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZMKafNMP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZMKafNMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8fJPmlsd_sendMessage(_c, 0, m);
  cMsg_wXZYKVrh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Wzqfqy88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8gVS9I5g_sendMessage(_c, 0, m);
  cMsg_T2YhvUIm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QhiiQUnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_EfY9uumo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EfY9uumo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qy80PnE7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_r0ZTIVYt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FMF63Tv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_GODob5xt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_osyRbBky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Uz54QxFJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Uz54QxFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WMwQN6U4, HV_BINOP_DIVIDE, 1, m, &cBinop_WMwQN6U4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qy80PnE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4C1Ig6p7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4C1Ig6p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iD2ndKwx, m);
}

void Heavy_WSTD_DL3Y::cMsg_sdFv7mFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_T1iUY2ZF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T1iUY2ZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QhiiQUnN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r0ZTIVYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vjLrYkOT, m);
}

void Heavy_WSTD_DL3Y::cBinop_GODob5xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_TYueIQds_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TYueIQds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WMwQN6U4, HV_BINOP_DIVIDE, 0, m, &cBinop_WMwQN6U4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WMwQN6U4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sdFv7mFc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yvZOSD5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zP4sOraf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zP4sOraf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pzz6lS3K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ur4CC4tO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_RgSXQ6Ex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_OG4JLuHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SfkDlHLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S31wkYgO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_S31wkYgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fVmxRlb7, HV_BINOP_DIVIDE, 1, m, &cBinop_fVmxRlb7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pzz6lS3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_co0rMgud_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_co0rMgud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RaJtEtDr, m);
}

void Heavy_WSTD_DL3Y::cMsg_vZbsFdTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_omROJaHU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_omROJaHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yvZOSD5z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ur4CC4tO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QVruoT5w, m);
}

void Heavy_WSTD_DL3Y::cBinop_OG4JLuHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_a6SstyEF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a6SstyEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fVmxRlb7, HV_BINOP_DIVIDE, 0, m, &cBinop_fVmxRlb7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fVmxRlb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vZbsFdTN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_MrNpvIbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_30Ry7vR9, HV_BINOP_MULTIPLY, 0, m, &cBinop_30Ry7vR9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JeDZfFbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_asXL1wvM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_asXL1wvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l42i8nK5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_30Ry7vR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Jxlsafkv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1yNtiCMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_30Ry7vR9, HV_BINOP_MULTIPLY, 1, m, &cBinop_30Ry7vR9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_l42i8nK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1yNtiCMp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jxlsafkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IOUKd0BF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IOUKd0BF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rtB0odpS_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LZsoioyI, m);
}

void Heavy_WSTD_DL3Y::cBinop_rtB0odpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GELHL6Aw, m);
}

void Heavy_WSTD_DL3Y::cVar_NeqdAKNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DlbRTiBd, HV_BINOP_MULTIPLY, 0, m, &cBinop_DlbRTiBd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rQCIhCaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nEt7WD7O_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_nEt7WD7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yYGt4O4H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DlbRTiBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5zh4haD6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gPwTeuX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DlbRTiBd, HV_BINOP_MULTIPLY, 1, m, &cBinop_DlbRTiBd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yYGt4O4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gPwTeuX2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5zh4haD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TBVVvjDL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TBVVvjDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3y9YPLHb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oLo0vntp, m);
}

void Heavy_WSTD_DL3Y::cBinop_3y9YPLHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_x336dEz1, m);
}

void Heavy_WSTD_DL3Y::sEnv_bAbrHjx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K0CqIZoC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b1D2AgcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Yo8JILt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_y5bXRsuk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0pkC4okk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_0MopKWQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oyFTPaEo, HV_BINOP_POW, 0, m, &cBinop_oyFTPaEo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oyFTPaEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GKLaX87T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Yg6FMgL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_3QbpiaTA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_b1D2AgcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yo8JILt7, 0, m, &cIf_Yo8JILt7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_K0CqIZoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BKUyOOBm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BKUyOOBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yo8JILt7, 1, m, &cIf_Yo8JILt7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0pkC4okk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Yg6FMgL2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_y5bXRsuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_GKLaX87T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3QbpiaTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oyFTPaEo, HV_BINOP_POW, 1, m, &cBinop_oyFTPaEo_sendMessage);
  cMsg_0MopKWQc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Kwu72uXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pVGXWQn2, HV_BINOP_MULTIPLY, 0, m, &cBinop_pVGXWQn2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YSkaO6hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PZ57AxtV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PZ57AxtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rQbX4Zyo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pVGXWQn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0dOrBlY7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Omgibror_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pVGXWQn2, HV_BINOP_MULTIPLY, 1, m, &cBinop_pVGXWQn2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rQbX4Zyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Omgibror_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0dOrBlY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ufiHjRWE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ufiHjRWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_sbmEd66v_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_svB0pd43, m);
}

void Heavy_WSTD_DL3Y::cBinop_sbmEd66v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lzRsk3RJ, m);
}

void Heavy_WSTD_DL3Y::cMsg_GKLaX87T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tqdaTc89_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tqdaTc89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rtjfwUpU, m);
}

void Heavy_WSTD_DL3Y::sEnv_vZgAywzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nnsA4Oba_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D5uIMCaM_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_NuZz3UQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QtE7bfQq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_F3HKxchQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_50lHNuqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dtQretUV, HV_BINOP_POW, 0, m, &cBinop_dtQretUV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dtQretUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L0uY5jit_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FpU4EhIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_1fU396dx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_D5uIMCaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NuZz3UQR, 0, m, &cIf_NuZz3UQR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nnsA4Oba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5VYoWCIC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5VYoWCIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NuZz3UQR, 1, m, &cIf_NuZz3UQR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F3HKxchQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FpU4EhIG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QtE7bfQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_L0uY5jit_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1fU396dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dtQretUV, HV_BINOP_POW, 1, m, &cBinop_dtQretUV_sendMessage);
  cMsg_50lHNuqV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_I8kREM0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8SbOFIVD, HV_BINOP_MULTIPLY, 0, m, &cBinop_8SbOFIVD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4QLduD5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FDmmvIjy_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_FDmmvIjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RHT0NxxK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8SbOFIVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_EwDxfgVn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7BjTLWub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8SbOFIVD, HV_BINOP_MULTIPLY, 1, m, &cBinop_8SbOFIVD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RHT0NxxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7BjTLWub_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EwDxfgVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QsM4pUI3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QsM4pUI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VJuDnhzY_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pZLZpwWB, m);
}

void Heavy_WSTD_DL3Y::cBinop_VJuDnhzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_b28JK72s, m);
}

void Heavy_WSTD_DL3Y::cMsg_L0uY5jit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4ntnwY8e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4ntnwY8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HXJdsKi5, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_aO6ZnNzM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3UG4yn41, 0, m, &cSlice_3UG4yn41_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PPnYrGfb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3UG4yn41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZIql4RLU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZIql4RLU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_SojMX6VO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZIql4RLU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ZIql4RLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LTuYjWZv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_YYcLg54I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_P74YHj9e_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_P74YHj9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Yow8Kgiv_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_TRhHzP45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TRhHzP45, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wIvoidfk, 0, m, &cDelay_wIvoidfk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TRhHzP45, 0, m, &cDelay_TRhHzP45_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LBpS7k3D, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_wIvoidfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wIvoidfk, m);
  cMsg_mi7B7Cdz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_1XapDlPv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_C1rqbAKR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_3SIXu2Zi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HWrFC0Kn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_2SDigbFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LrobD4dC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TRhHzP45, 2, m, &cDelay_TRhHzP45_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SOVUbJxB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HWrFC0Kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2SDigbFI, 0, m, &hTable_2SDigbFI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Yow8Kgiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_3SIXu2Zi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mi7B7Cdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2SDigbFI, 0, m, &hTable_2SDigbFI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SOVUbJxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TRhHzP45, 0, m, &cDelay_TRhHzP45_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LrobD4dC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wIvoidfk, 2, m, &cDelay_wIvoidfk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_C1rqbAKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LBpS7k3D, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_Kfps82ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YLWJGWK8, HV_BINOP_SUBTRACT, 0, m, &cBinop_YLWJGWK8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MhzcVYaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2ceaDqMf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_2ceaDqMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rVFR9TXr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MG9wmBeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E3OVL5F7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_xCgDs6ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xCgDs6ww, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qthurju8, 0, m, &cDelay_Qthurju8_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CtZzHWZD, 0, m, &sTabread_CtZzHWZD_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Qthurju8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Qthurju8, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CtZzHWZD, 0, m, &sTabread_CtZzHWZD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qthurju8, 0, m, &cDelay_Qthurju8_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_CtZzHWZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_H9NLToeJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_H9NLToeJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_1PkQxAs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eEdiox49, HV_BINOP_MAX, 0, m, &cBinop_eEdiox49_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rVFR9TXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1PkQxAs4, HV_BINOP_MULTIPLY, 0, m, &cBinop_1PkQxAs4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YLWJGWK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hCYoayPq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CtZzHWZD, 0, m, &sTabread_CtZzHWZD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5ZPSBqUC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_AS86gIOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H9NLToeJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_H9NLToeJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qthurju8, 2, m, &cDelay_Qthurju8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_E3OVL5F7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AS86gIOF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hCYoayPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xCgDs6ww, 0, m, &cDelay_xCgDs6ww_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qthurju8, 0, m, &cDelay_Qthurju8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ix29lat8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_eEdiox49, HV_BINOP_MAX, 1, m, &cBinop_eEdiox49_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eEdiox49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YLWJGWK8, HV_BINOP_SUBTRACT, 1, m, &cBinop_YLWJGWK8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5ZPSBqUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xCgDs6ww, 0, m, &cDelay_xCgDs6ww_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ww2jLl5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xCgDs6ww, 2, m, &cDelay_xCgDs6ww_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H9NLToeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ww2jLl5c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oJT5KUgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MG9wmBeV, 0, m, &cVar_MG9wmBeV_sendMessage);
  cMsg_MhzcVYaR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Kfps82ov, 0, m, &cTabhead_Kfps82ov_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3ia8tmQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LVBBMp1A_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_LVBBMp1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_74tUL9zq_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ju4x0HVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ju4x0HVI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oihMj5BV, 0, m, &cDelay_oihMj5BV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ju4x0HVI, 0, m, &cDelay_ju4x0HVI_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_a02eutDN, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_oihMj5BV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oihMj5BV, m);
  cMsg_pJqedd2I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5cRLCwcs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vWSiCfAb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_3hyXWyqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xs1xFnWW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_Y4T68Ejp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wPm2kXOs_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ju4x0HVI, 2, m, &cDelay_ju4x0HVI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JRPhoZvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xs1xFnWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Y4T68Ejp, 0, m, &hTable_Y4T68Ejp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_74tUL9zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_3hyXWyqd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pJqedd2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Y4T68Ejp, 0, m, &hTable_Y4T68Ejp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JRPhoZvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ju4x0HVI, 0, m, &cDelay_ju4x0HVI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wPm2kXOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_oihMj5BV, 2, m, &cDelay_oihMj5BV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vWSiCfAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_a02eutDN, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_3rADAviv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3gPbEPNu, HV_BINOP_SUBTRACT, 0, m, &cBinop_3gPbEPNu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rnrbc9gV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HhhTK1OA_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_HhhTK1OA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VFBz3noZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ge7OnMJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lhBqGKCs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_NvRPtXmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NvRPtXmN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qUNKvCHI, 0, m, &cDelay_qUNKvCHI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SyMbVr0O, 0, m, &sTabread_SyMbVr0O_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_qUNKvCHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qUNKvCHI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SyMbVr0O, 0, m, &sTabread_SyMbVr0O_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qUNKvCHI, 0, m, &cDelay_qUNKvCHI_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_SyMbVr0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_4hSqpDYT, HV_BINOP_SUBTRACT, 0, m, &cBinop_4hSqpDYT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_o2IGTXmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7m3QvWH, HV_BINOP_MAX, 0, m, &cBinop_h7m3QvWH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VFBz3noZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o2IGTXmX, HV_BINOP_MULTIPLY, 0, m, &cBinop_o2IGTXmX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3gPbEPNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sE1QUALI_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SyMbVr0O, 0, m, &sTabread_SyMbVr0O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R1vhBGy8_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_GsOPcB2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hSqpDYT, HV_BINOP_SUBTRACT, 1, m, &cBinop_4hSqpDYT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qUNKvCHI, 2, m, &cDelay_qUNKvCHI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lhBqGKCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GsOPcB2x_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sE1QUALI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NvRPtXmN, 0, m, &cDelay_NvRPtXmN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qUNKvCHI, 0, m, &cDelay_qUNKvCHI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_U0mfocWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7m3QvWH, HV_BINOP_MAX, 1, m, &cBinop_h7m3QvWH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h7m3QvWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3gPbEPNu, HV_BINOP_SUBTRACT, 1, m, &cBinop_3gPbEPNu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_R1vhBGy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NvRPtXmN, 0, m, &cDelay_NvRPtXmN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HufzfVMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NvRPtXmN, 2, m, &cDelay_NvRPtXmN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4hSqpDYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HufzfVMG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_36vsvNjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ge7OnMJZ, 0, m, &cVar_ge7OnMJZ_sendMessage);
  cMsg_rnrbc9gV_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3rADAviv, 0, m, &cTabhead_3rADAviv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_a5itvoCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5CHQrvtL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ObloUB6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YmVBXEZM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_amBechsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v6r3QXog, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4OxFwXJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IFhTHKi1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_T2YhvUIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aB3XDVck, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8fJPmlsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cMGsPYMu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8gVS9I5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HvyAKPVz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wXZYKVrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XBJlmObX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_mVprwGoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rLPEOA1t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O5ibZq7n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_t1s4A1it_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rLPEOA1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mVprwGoi, 1, m, &cVar_mVprwGoi_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Ihd4AkXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_kW333plv, 0, m, &cVar_kW333plv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_1VaZpF9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_kW333plv, 0, m, &cVar_kW333plv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_sg7O6g1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1VaZpF9y, 0, m, &cIf_1VaZpF9y_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_SGahUbph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ihd4AkXs, 0, m, &cIf_Ihd4AkXs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9KCz3Weo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0TeufFe0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TSxkzEbg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qKJLugKf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0TeufFe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9KCz3Weo, 1, m, &cVar_9KCz3Weo_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_jk6bS1gA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_JhEhH5rO, 0, m, &cVar_JhEhH5rO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_7JyyIvC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_JhEhH5rO, 0, m, &cVar_JhEhH5rO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_AGCYOSix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7JyyIvC4, 0, m, &cIf_7JyyIvC4_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_vltitniV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jk6bS1gA, 0, m, &cIf_jk6bS1gA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9vtC2iTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RLTMrEjf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GN6vxctc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KADXSNad_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RLTMrEjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9vtC2iTf, 1, m, &cVar_9vtC2iTf_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_zsMRKFO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_gTOE3GeV, 0, m, &cVar_gTOE3GeV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_P4CJBV8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_gTOE3GeV, 0, m, &cVar_gTOE3GeV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_VldcZ6qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P4CJBV8T, 0, m, &cIf_P4CJBV8T_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uSfkmWQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zsMRKFO9, 0, m, &cIf_zsMRKFO9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Z091udTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TRmVswuH, HV_BINOP_DIVIDE, 0, m, &cBinop_TRmVswuH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_3TDg6Kvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NwkvZ0Yj, HV_BINOP_MULTIPLY, 1, m, &cBinop_NwkvZ0Yj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3wtTZuoT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LvoUR2tC, 0, m, &cSlice_LvoUR2tC_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LJr5Pee7, 0, m, &cSlice_LJr5Pee7_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_leSQ8gCg_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GKsBjNLg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_LvoUR2tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_TsqfhV0y, 0, m, &cVar_TsqfhV0y_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TsqfhV0y, 0, m, &cVar_TsqfhV0y_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_LJr5Pee7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_BxE98gUb, HV_BINOP_NEQ, 1, m, &cBinop_BxE98gUb_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TsqfhV0y, 1, m, &cVar_TsqfhV0y_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_BxE98gUb, HV_BINOP_NEQ, 1, m, &cBinop_BxE98gUb_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TsqfhV0y, 1, m, &cVar_TsqfhV0y_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_TsqfhV0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_0NAQOC4I_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_vujapMr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_owyik7yc_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aLkwoKh1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_owyik7yc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BxE98gUb, HV_BINOP_NEQ, 1, m, &cBinop_BxE98gUb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aLkwoKh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TsqfhV0y, 0, m, &cVar_TsqfhV0y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BxE98gUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vujapMr7, 1, m, &cIf_vujapMr7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_leSQ8gCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BxE98gUb, HV_BINOP_NEQ, 0, m, &cBinop_BxE98gUb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GKsBjNLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vujapMr7, 0, m, &cIf_vujapMr7_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_KPu9MNSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GSpbWyCY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qhwVYhs7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_MknX5ADZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3SCCd3w3_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PszNBHSg_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KW0ddQeT_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1xmlHNaT_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Z4qBJzW_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ODsHP0gn_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b8omaoMy_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HpJybd2g_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w72ynq8u_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uHqMTuft_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tB6051EL_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Vnpu2LG_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zBtRiLHd_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_3SCCd3w3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nioukysK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PszNBHSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ok1qgHR1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_KW0ddQeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tLyJRTGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_1xmlHNaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DQANYgeX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5Z4qBJzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a6Fn5kVa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ODsHP0gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m9eQvHHt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_b8omaoMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rrOFPh3U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HpJybd2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CZagTtis_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_w72ynq8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D4IQXQe4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uHqMTuft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VXJoBanV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_tB6051EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oJfXeoCG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0Vnpu2LG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r9KeYaw4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zBtRiLHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W83aCUdN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TRmVswuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NwkvZ0Yj, HV_BINOP_MULTIPLY, 0, m, &cBinop_NwkvZ0Yj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NwkvZ0Yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3wtTZuoT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_GSpbWyCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TRmVswuH, HV_BINOP_DIVIDE, 1, m, &cBinop_TRmVswuH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qhwVYhs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z091udTh, 0, m, &cVar_Z091udTh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3TDg6Kvh, 0, m, &cVar_3TDg6Kvh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CylTaIhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z091udTh, 0, m, &cVar_Z091udTh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_79O6VR7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3TDg6Kvh, 0, m, &cVar_3TDg6Kvh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nioukysK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ok1qgHR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tLyJRTGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DQANYgeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_a6Fn5kVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m9eQvHHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rrOFPh3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CZagTtis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_D4IQXQe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VXJoBanV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oJfXeoCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_r9KeYaw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W83aCUdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79O6VR7m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CylTaIhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xGHy34jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GbwFRszW, HV_BINOP_DIVIDE, 0, m, &cBinop_GbwFRszW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_vwuN0WQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oG4dNhkj, HV_BINOP_MULTIPLY, 1, m, &cBinop_oG4dNhkj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_X6Ivdc6l_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NAQPIfPx, 0, m, &cSlice_NAQPIfPx_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ph3XhQuF, 0, m, &cSlice_ph3XhQuF_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIF1FlkJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kHXsTt85_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_NAQPIfPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_8Z6p9VoX, 0, m, &cVar_8Z6p9VoX_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_8Z6p9VoX, 0, m, &cVar_8Z6p9VoX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_ph3XhQuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YbUQHla7, HV_BINOP_NEQ, 1, m, &cBinop_YbUQHla7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_8Z6p9VoX, 1, m, &cVar_8Z6p9VoX_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YbUQHla7, HV_BINOP_NEQ, 1, m, &cBinop_YbUQHla7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_8Z6p9VoX, 1, m, &cVar_8Z6p9VoX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_8Z6p9VoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_kVStWL6t_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_MWCYOd6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5yfMvh7J_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ywvrQ5x_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_4ywvrQ5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Z6p9VoX, 0, m, &cVar_8Z6p9VoX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5yfMvh7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YbUQHla7, HV_BINOP_NEQ, 1, m, &cBinop_YbUQHla7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YbUQHla7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MWCYOd6n, 1, m, &cIf_MWCYOd6n_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aIF1FlkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YbUQHla7, HV_BINOP_NEQ, 0, m, &cBinop_YbUQHla7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kHXsTt85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MWCYOd6n, 0, m, &cIf_MWCYOd6n_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VQ0xra4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5lwKKeKF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fxYENasX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_xQryIVco_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JFDYC0HG_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AMdzhmCN_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dykQ2Ns0_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8csWhUwU_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xOfvUHRO_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_082IO2u1_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GcWfdDF0_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vWgDx0fe_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_syIn8Gh1_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2EM5GfX9_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oHFWAAg0_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UA3g5fSF_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XT8y98FK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_JFDYC0HG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kaZtdHQ2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_AMdzhmCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iCIzZFCb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dykQ2Ns0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ysny2XXt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_8csWhUwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V8k1QwcT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_xOfvUHRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_br0dLTjP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_082IO2u1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P6ZrZMVo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_GcWfdDF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V8KOLBfl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_vWgDx0fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WYUXbtlR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_syIn8Gh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_prYni2J6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2EM5GfX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uoNU1b1n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_oHFWAAg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cJmw35YS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_UA3g5fSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TWUBsh8R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XT8y98FK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PXSz5FTq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GbwFRszW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oG4dNhkj, HV_BINOP_MULTIPLY, 0, m, &cBinop_oG4dNhkj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oG4dNhkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_X6Ivdc6l_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_fxYENasX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xGHy34jo, 0, m, &cVar_xGHy34jo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vwuN0WQ4, 0, m, &cVar_vwuN0WQ4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5lwKKeKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GbwFRszW, HV_BINOP_DIVIDE, 1, m, &cBinop_GbwFRszW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4jdRtwIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xGHy34jo, 0, m, &cVar_xGHy34jo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_edyyTArZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vwuN0WQ4, 0, m, &cVar_vwuN0WQ4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kaZtdHQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iCIzZFCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ysny2XXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_V8k1QwcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_br0dLTjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P6ZrZMVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_V8KOLBfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WYUXbtlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_prYni2J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uoNU1b1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cJmw35YS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TWUBsh8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PXSz5FTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edyyTArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jdRtwIK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_jivRNL0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9VaknWYe, HV_BINOP_DIVIDE, 0, m, &cBinop_9VaknWYe_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_aPrGTfwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_loVjtXab, HV_BINOP_MULTIPLY, 1, m, &cBinop_loVjtXab_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_rZyEFNgQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_90nUyomV, 0, m, &cSlice_90nUyomV_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r8RI7OJt, 0, m, &cSlice_r8RI7OJt_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PiSZTXyP_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gAQ7Mo4z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_90nUyomV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_nScX1eb6, 0, m, &cVar_nScX1eb6_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_nScX1eb6, 0, m, &cVar_nScX1eb6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_r8RI7OJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ODHbiZpc, HV_BINOP_NEQ, 1, m, &cBinop_ODHbiZpc_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_nScX1eb6, 1, m, &cVar_nScX1eb6_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ODHbiZpc, HV_BINOP_NEQ, 1, m, &cBinop_ODHbiZpc_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_nScX1eb6, 1, m, &cVar_nScX1eb6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_nScX1eb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_EpSZQZf7_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_YD1NMwx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A6LFDcTP_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l7h85oOR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_A6LFDcTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ODHbiZpc, HV_BINOP_NEQ, 1, m, &cBinop_ODHbiZpc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l7h85oOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nScX1eb6, 0, m, &cVar_nScX1eb6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ODHbiZpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YD1NMwx1, 1, m, &cIf_YD1NMwx1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gAQ7Mo4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YD1NMwx1, 0, m, &cIf_YD1NMwx1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PiSZTXyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ODHbiZpc, HV_BINOP_NEQ, 0, m, &cBinop_ODHbiZpc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2xkrVAsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TVtnaVBJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZNaSSref_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_VPYNl9OS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r43SJp5o_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WQqvxucX_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WODs6TlS_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bQZWMMXp_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KCnz1Ykd_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ybxoBDYM_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d0NrpTIC_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qIsN1Xy4_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lre5dnaj_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KXdtVu40_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X0HKt6rW_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y49qa0Gv_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WxoCjrFF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_r43SJp5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yHcm6OAV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WQqvxucX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9W3SHWIf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WODs6TlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oLyWKcQA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_bQZWMMXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0jiwtT8C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_KCnz1Ykd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GeWbHc9S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ybxoBDYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eW1Q8MKh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_d0NrpTIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XmykMj4G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qIsN1Xy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_89z26UUT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lre5dnaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1cD0A0k1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_KXdtVu40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4gTNv66Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_X0HKt6rW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bDFVcIZg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_y49qa0Gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0SqvrJWk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WxoCjrFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TJaMWeZK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9VaknWYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_loVjtXab, HV_BINOP_MULTIPLY, 0, m, &cBinop_loVjtXab_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_loVjtXab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rZyEFNgQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_ZNaSSref_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jivRNL0z, 0, m, &cVar_jivRNL0z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aPrGTfwu, 0, m, &cVar_aPrGTfwu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TVtnaVBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9VaknWYe, HV_BINOP_DIVIDE, 1, m, &cBinop_9VaknWYe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U6b49gva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jivRNL0z, 0, m, &cVar_jivRNL0z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YxY4wCW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aPrGTfwu, 0, m, &cVar_aPrGTfwu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yHcm6OAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9W3SHWIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oLyWKcQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0jiwtT8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GeWbHc9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eW1Q8MKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XmykMj4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_89z26UUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1cD0A0k1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4gTNv66Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bDFVcIZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0SqvrJWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TJaMWeZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YxY4wCW8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6b49gva_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G6HT297I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CvwSeWX0_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_BK3dtbkb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7DfE6JiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CvwSeWX0_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_BK3dtbkb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kjXMSWae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CvwSeWX0_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_BK3dtbkb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lfITEaeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CvwSeWX0_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_BK3dtbkb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JHZxZ2hR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CvwSeWX0_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_BK3dtbkb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DFNQ7raB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_iGCmUxE5, 0, m, &cVar_iGCmUxE5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J2EdFk2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_LzztLcYc, 0, m, &cVar_LzztLcYc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B4rRIqFW, 0, m, &cVar_B4rRIqFW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4aE1sgS3, 0, m, &cVar_4aE1sgS3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hXyq3chg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zHPCiEr1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pVs4hn0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zHPCiEr1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_PuGhnd3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CAq5BeJY, 0, m, &cVar_CAq5BeJY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QGhVYj6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EkcRcnNg, 0, m, &cVar_EkcRcnNg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xnG2hMLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_65RMxHSF, 0, m, &cVar_65RMxHSF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pul3hgjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zHPCiEr1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EqtU0Q3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zHPCiEr1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WJcZqZ5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iZvgxWHp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7gJ3fabU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iZvgxWHp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_lFBCaDAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DdpKo0v7, 0, m, &cVar_DdpKo0v7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_06EqYb2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sIy2ju4I, 0, m, &cVar_sIy2ju4I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_15DkOzHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GuTTrRUb, 0, m, &cVar_GuTTrRUb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GY8Ft1O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iZvgxWHp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_R4jJ11sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iZvgxWHp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Xjk2Rtj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yxTYYvrW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5V1aihon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yxTYYvrW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_T5K4Wjj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6Lt3xio0, 0, m, &cVar_6Lt3xio0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SfXZLDmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y6UKHuvy, 0, m, &cVar_y6UKHuvy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o9Nr6rxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cg6BIfZB, 0, m, &cVar_Cg6BIfZB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZczpVTVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yxTYYvrW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TdBj9axc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yxTYYvrW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_0NAQOC4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SGahUbph, 0, m, &cVar_SGahUbph_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t1s4A1it_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SAGWseq2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HoGHPc8E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O5ibZq7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bIo7imWP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UY9bgnRi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UY9bgnRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sg7O6g1V, 0, m, &cVar_sg7O6g1V_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bIo7imWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1VaZpF9y, 1, m, &cIf_1VaZpF9y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SAGWseq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ihd4AkXs, 1, m, &cIf_Ihd4AkXs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HoGHPc8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SGahUbph, 0, m, &cVar_SGahUbph_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kVStWL6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vltitniV, 0, m, &cVar_vltitniV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qKJLugKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeW2PHt6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rY3RAQNv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TSxkzEbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mDzF8EJ7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YsiAAe9H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mDzF8EJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7JyyIvC4, 1, m, &cIf_7JyyIvC4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YsiAAe9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AGCYOSix, 0, m, &cVar_AGCYOSix_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rY3RAQNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vltitniV, 0, m, &cVar_vltitniV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yeW2PHt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jk6bS1gA, 1, m, &cIf_jk6bS1gA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EpSZQZf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uSfkmWQx, 0, m, &cVar_uSfkmWQx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KADXSNad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WFY9Rc8f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZFc8RoDT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GN6vxctc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8IH1G16U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WcLE1fTb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WcLE1fTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VldcZ6qy, 0, m, &cVar_VldcZ6qy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8IH1G16U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P4CJBV8T, 1, m, &cIf_P4CJBV8T_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZFc8RoDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uSfkmWQx, 0, m, &cVar_uSfkmWQx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WFY9Rc8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zsMRKFO9, 1, m, &cIf_zsMRKFO9_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xAVmnkjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LzztLcYc, 0, m, &cVar_LzztLcYc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CIWE3764_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B4rRIqFW, 0, m, &cVar_B4rRIqFW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Y3E5Myxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4aE1sgS3, 0, m, &cVar_4aE1sgS3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AaAkHgZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0e6oZMxd, 0, m, &cVar_0e6oZMxd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GDcOZFO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DrGkBJka_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y5kiO9Am_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8AdG0UVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JC75pLO8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fg2Xba0C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S9wAiGJf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FYVVtasz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n3pvo66n_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ITvf5BCn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T04j9ap2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nBO0VYqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ukgKxsJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y6X2lF9m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LcRaS21M_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wFaawDjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3NhkKqdw_sendMessage(_c, 0, m);
  cMsg_udOyROX4_sendMessage(_c, 0, m);
  cMsg_TIHYa53e_sendMessage(_c, 0, m);
  cMsg_fGhKJRt0_sendMessage(_c, 0, m);
  cMsg_iXVY1R86_sendMessage(_c, 0, m);
  cMsg_6vgHsrfe_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bb8dcoSk, 0, m, &cVar_bb8dcoSk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0e6oZMxd, 0, m, &cVar_0e6oZMxd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x8EI0wk5, 0, m, &cVar_x8EI0wk5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_srNpwRyP, 0, m, &cVar_srNpwRyP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dLfxWxiC, 0, m, &cVar_dLfxWxiC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8G1o3Ixx, 0, m, &cVar_8G1o3Ixx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Df9dZLlm, 0, m, &cVar_Df9dZLlm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c0j7NZGh, 0, m, &cVar_c0j7NZGh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0t2IY2G0, 0, m, &cVar_0t2IY2G0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UHpyF3zH, 0, m, &cVar_UHpyF3zH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s3egpIrA, 0, m, &cVar_s3egpIrA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5JzMhTuJ, 0, m, &cVar_5JzMhTuJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yzXQ9Wpb, 0, m, &cVar_yzXQ9Wpb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UbeD2fzP, 0, m, &cVar_UbeD2fzP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6huIPzbe, 0, m, &cVar_6huIPzbe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DiWzRs1T, 0, m, &cVar_DiWzRs1T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W2ZIFUYj, 0, m, &cVar_W2ZIFUYj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1dwSsGsm, 0, m, &cVar_1dwSsGsm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BWDko8m5, 0, m, &cVar_BWDko8m5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xVTILxzO, 0, m, &cVar_xVTILxzO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3zntZfTD, 0, m, &cVar_3zntZfTD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_emk0YOaG, 0, m, &cVar_emk0YOaG_sendMessage);
  cMsg_FOwcVR2P_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RwkghXtC, 0, m, &cVar_RwkghXtC_sendMessage);
  cMsg_OcAgL7Sn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LTX87KUK, 0, m, &cVar_LTX87KUK_sendMessage);
  cMsg_1WJz54nz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kvHiK7dt, 0, m, &cVar_kvHiK7dt_sendMessage);
  cMsg_cByicscP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CPdJAFYo, 0, m, &cVar_CPdJAFYo_sendMessage);
  cMsg_YSkaO6hh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Kwu72uXX, 0, m, &cVar_Kwu72uXX_sendMessage);
  cMsg_4QLduD5P_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_I8kREM0T, 0, m, &cVar_I8kREM0T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UbChdC6O, 0, m, &cVar_UbChdC6O_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R0YmKN59, 0, m, &cVar_R0YmKN59_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RXhXU9dS, 0, m, &cVar_RXhXU9dS_sendMessage);
  cMsg_C4gWZ4n0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eylp7s1f, 0, m, &cVar_eylp7s1f_sendMessage);
  cMsg_DOs7XovF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_D8Pcv1aD, 0, m, &cVar_D8Pcv1aD_sendMessage);
  cMsg_J7bAmXff_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_d19RT6Bu, 0, m, &cVar_d19RT6Bu_sendMessage);
  cMsg_DVSvHOFe_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bx89yx6D, 0, m, &cVar_bx89yx6D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9uf78VUI, 0, m, &cVar_9uf78VUI_sendMessage);
  cMsg_XUPh1a1o_sendMessage(_c, 0, m);
  cMsg_y3K88II9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5x10O98S, 0, m, &cVar_5x10O98S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E1WbXSlV, 0, m, &cVar_E1WbXSlV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B8KOLt4y, 0, m, &cVar_B8KOLt4y_sendMessage);
  cMsg_hnsmUEju_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gONEQ4Z5, 0, m, &cVar_gONEQ4Z5_sendMessage);
  cMsg_jaBV8L9M_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lcDExF26, 0, m, &cVar_lcDExF26_sendMessage);
  cMsg_dM17KubM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QUbP8eKY, 0, m, &cVar_QUbP8eKY_sendMessage);
  cMsg_D7HLf3Ze_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Dlj2t921, 0, m, &cVar_Dlj2t921_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XaU7Sz0H, 0, m, &cVar_XaU7Sz0H_sendMessage);
  cMsg_k0Lp8x4R_sendMessage(_c, 0, m);
  cMsg_ZCZlUCPz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bTOTsKue, 0, m, &cVar_bTOTsKue_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pO07ndbi, 0, m, &cVar_pO07ndbi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5sqogDZn, 0, m, &cVar_5sqogDZn_sendMessage);
  cMsg_osyRbBky_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FMF63Tv4, 0, m, &cVar_FMF63Tv4_sendMessage);
  cMsg_SfkDlHLh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RgSXQ6Ex, 0, m, &cVar_RgSXQ6Ex_sendMessage);
  cMsg_JeDZfFbB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MrNpvIbQ, 0, m, &cVar_MrNpvIbQ_sendMessage);
  cMsg_rQCIhCaZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NeqdAKNK, 0, m, &cVar_NeqdAKNK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SojMX6VO, 0, m, &cVar_SojMX6VO_sendMessage);
  cMsg_YYcLg54I_sendMessage(_c, 0, m);
  cMsg_3ia8tmQJ_sendMessage(_c, 0, m);
  cMsg_J2EdFk2y_sendMessage(_c, 0, m);
  cMsg_DFNQ7raB_sendMessage(_c, 0, m);
  cMsg_54HOC8yp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EBLqxK4p, 0, m, &cVar_EBLqxK4p_sendMessage);
  cMsg_g4l6vCSs_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FvjB1YIG, 0, m, &cTabhead_FvjB1YIG_sendMessage);
  cMsg_Lej6rWrK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_z6BltCi5, 0, m, &cVar_z6BltCi5_sendMessage);
  cMsg_NdlHywCd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7dZD0CDJ, 0, m, &cTabhead_7dZD0CDJ_sendMessage);
  cMsg_wYaPrkRV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jcDNXssg, 0, m, &cVar_jcDNXssg_sendMessage);
  cMsg_Pm6FZweL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_T0sUfdBM, 0, m, &cTabhead_T0sUfdBM_sendMessage);
  cMsg_pfRqi2Vx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kugbDvZO, 0, m, &cVar_kugbDvZO_sendMessage);
  cMsg_DA3FjjoM_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vKb9CMYG, 0, m, &cTabhead_vKb9CMYG_sendMessage);
  cMsg_Ix29lat8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MG9wmBeV, 0, m, &cVar_MG9wmBeV_sendMessage);
  cMsg_MhzcVYaR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Kfps82ov, 0, m, &cTabhead_Kfps82ov_sendMessage);
  cMsg_U0mfocWj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ge7OnMJZ, 0, m, &cVar_ge7OnMJZ_sendMessage);
  cMsg_rnrbc9gV_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3rADAviv, 0, m, &cTabhead_3rADAviv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_l8CgjMx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XP9VsMr3, HV_BINOP_MULTIPLY, 0, m, &cBinop_XP9VsMr3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_6VVuGXHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vor0775W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vQAi91G9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KENhhsDQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_KAsbSVuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gDWlPwm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gLaw1gBe_sendMessage);
  cMsg_ffBu1g2T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_P4NTg8NI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Izz07OIj, HV_BINOP_MULTIPLY, 0, m, &cBinop_Izz07OIj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_0PEKeT99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_USraVv2h_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YF96WmzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cb1AkErg, HV_BINOP_MULTIPLY, 1, m, &cBinop_cb1AkErg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fa6Mrpwx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_x1mwhtHG_sendMessage);
  cMsg_bFCluFvl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_1RMEelH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BKcGlzlW, HV_BINOP_MULTIPLY, 0, m, &cBinop_BKcGlzlW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_DmRqeUDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zvgtpymn_sendMessage(_c, 0, m);
  cMsg_eZgXrhRb_sendMessage(_c, 0, m);
  cMsg_eVzZFn0v_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Zj9PQ8kp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nQxi0Eeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8Esu7zF1_sendMessage);
  cMsg_GHlrBTIK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_CINtlk0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dLfxWxiC, 0, m, &cVar_dLfxWxiC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VX77yWG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O8IsXSB0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zw1bOPqP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hDGyZFGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tltcF8K9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s8x4OrCi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_90ociHKx_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_yx5UxUba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V79jwkcv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NRWYXJgw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5q8p9yaI_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_2cHyo2C8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7KvgGq4m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dJtIUnrP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aWMZ0HA2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NHvwYyeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nfDeghfY, HV_BINOP_MULTIPLY, 0, m, &cBinop_nfDeghfY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MHgaDBcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cX2uTuGk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6yV5X5aY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ByWluOmf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_tBmaS0cM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5BD8Iqif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_X6xR35zN_sendMessage);
  cMsg_bLO3wOEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_SxXu2IbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UL93fpcB, HV_BINOP_MULTIPLY, 0, m, &cBinop_UL93fpcB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FfC7h50X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_l0xpAXSp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_V3Bjsuj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JMhqUXOO, HV_BINOP_MULTIPLY, 1, m, &cBinop_JMhqUXOO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ewo0hBnq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KDoagzq6_sendMessage);
  cMsg_wQzsSJDH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_XCZrvY9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K1Piue1l, HV_BINOP_MULTIPLY, 0, m, &cBinop_K1Piue1l_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bu4iSiFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DDtCEYlu_sendMessage(_c, 0, m);
  cMsg_7MQZpctI_sendMessage(_c, 0, m);
  cMsg_8eiaOLl1_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_aCqMDLbl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_afWdFgXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gjlbKlNU_sendMessage);
  cMsg_xmYwHype_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_rauuwxI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iGCmUxE5, 0, m, &cVar_iGCmUxE5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NmoiFV9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_PuGhnd3a_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZjHOXT5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QGhVYj6X_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_J9yiTXU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_xnG2hMLm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uw7a7hy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_lFBCaDAP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3zpFIXVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_06EqYb2d_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_asrSXUeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_T5K4Wjj8_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MThobnlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SfXZLDmJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_OSGtZO6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_o9Nr6rxD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hh2H21FA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_15DkOzHD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CkCQ85nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h8aTTjn9, HV_BINOP_MULTIPLY, 1, m, &cBinop_h8aTTjn9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xcLvft77_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oISgB9C0, HV_BINOP_MULTIPLY, 1, m, &cBinop_oISgB9C0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EnuIafT9_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qr36bNun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LHOdVape, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_s83PKJW2, m);
}

void Heavy_WSTD_DL3Y::cReceive_6RiIExtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OKbGjADI_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_u88eovKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Gi0Oe7sf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jJq7P1hF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wl25FzEg, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wl25FzEg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_scElCIDs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GASsbMoK, HV_BINOP_MULTIPLY, 1, m, &cBinop_GASsbMoK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ywhcPMqi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xL7JRL9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XnfwZdb2, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GrNr1xC0, m);
}

void Heavy_WSTD_DL3Y::cReceive_kFiPBE2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_p7qh7AgK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MxpDbN6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qJzFj7Zv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nIp0rFn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1PkQxAs4, HV_BINOP_MULTIPLY, 1, m, &cBinop_1PkQxAs4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oJT5KUgv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_o2IGTXmX, HV_BINOP_MULTIPLY, 1, m, &cBinop_o2IGTXmX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_36vsvNjw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_LTuYjWZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ltg8E5jn, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_daQX3ia4, m);
}

void Heavy_WSTD_DL3Y::cReceive_uyPxIws0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_E2LKdOWg_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VtuDC3Jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hXhEuifT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Jsw3Jas8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sg7O6g1V, 0, m, &cVar_sg7O6g1V_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FXz3F7GT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mVprwGoi, 0, m, &cVar_mVprwGoi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wr0ovAjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9KCz3Weo, 0, m, &cVar_9KCz3Weo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1RRNSWfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AGCYOSix, 0, m, &cVar_AGCYOSix_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7XxwxxYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VldcZ6qy, 0, m, &cVar_VldcZ6qy_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HSrIgGBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9vtC2iTf, 0, m, &cVar_9vtC2iTf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_2PP068sL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KPu9MNSV, 0, m, &cVar_KPu9MNSV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VQ0xra4U, 0, m, &cVar_VQ0xra4U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2xkrVAsD, 0, m, &cVar_2xkrVAsD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EIDwrQld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xQryIVco_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_s1IINFvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MknX5ADZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_8mEswe5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VPYNl9OS_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_ZvAgF9N8, VOf(Bf0));
    __hv_line_f(&sLine_we3l5QFX, VOf(Bf1));
    __hv_line_f(&sLine_F87eOyfa, VOf(Bf2));
    __hv_line_f(&sLine_HyU76aGI, VOf(Bf3));
    __hv_line_f(&sLine_8C7CWo4U, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_TJuaseFU, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Ma9vMFrN, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_wnDeZ73n, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_5IFJj3U6, VOf(Bf1));
    __hv_line_f(&sLine_AsHt4w2x, VOf(Bf0));
    __hv_line_f(&sLine_0ef5wMEw, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_IWJxlgrL, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_yPuZhdyW, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_nJK8s5ew, VOf(Bf5));
    __hv_line_f(&sLine_PUlM3jbL, VOf(Bf1));
    __hv_line_f(&sLine_beccf2W7, VOf(Bf2));
    __hv_line_f(&sLine_j1dsbIxQ, VOf(Bf4));
    __hv_line_f(&sLine_qugRxuIp, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_3kVuIKOD, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_YGEuvxlp, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_5C7ihpwN, VOf(Bf6));
    __hv_line_f(&sLine_5Lu03wVh, VOf(Bf2));
    __hv_line_f(&sLine_1465mirn, VOf(Bf1));
    __hv_line_f(&sLine_BjT1Dq6i, VOf(Bf5));
    __hv_line_f(&sLine_A9mgmbG8, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_hB9JTZ7E, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_VEsORcS7, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_0dLIN6A7, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_PHeP7A0y, VOf(Bf2));
    __hv_line_f(&sLine_hafV42BE, VOf(Bf6));
    __hv_line_f(&sLine_0SpwpJPL, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_O3idtb1u, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_SOvOdmT7, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_SYcW4oJO, VOf(Bf8));
    __hv_line_f(&sLine_ODGBWXBW, VOf(Bf2));
    __hv_line_f(&sLine_BtsKVKf3, VOf(Bf1));
    __hv_line_f(&sLine_r6h6C8In, VOf(Bf7));
    __hv_line_f(&sLine_NP6lxrdh, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_D6W79cbI, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_8vgK8q2A, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_IUL07AzI, VOf(Bf9));
    __hv_tabread_f(&sTabread_BVxw12tT, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_CuuPYCt1, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_mSzajeyt, VOf(Bf9));
    __hv_tabread_f(&sTabread_alXsi6o1, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_qpYvlRBI, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_zY6BSVsx, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_otbMVUga, VOf(Bf3));
    __hv_rpole_f(&sRPole_FRt1Frue, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_RjucjkbO, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_1AC8qUtn, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_2GitFjeT, VIf(Bf3));
    __hv_varread_f(&sVarf_pmp1WIHH, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_2beDsilW, VOf(Bf5));
    __hv_rpole_f(&sRPole_oZimjQoc, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_rDdRTDNV, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_K8wUAsoQ, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_0UsS9AuZ, VIf(Bf5));
    __hv_varread_f(&sVarf_LHOdVape, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_bK64IFnG, VOf(Bf1));
    __hv_varread_f(&sVarf_s83PKJW2, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_QFkLIRGx, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_tLsFDF0J, VOf(Bf1));
    __hv_varread_f(&sVarf_VUO83LzB, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_YkZDzIKr, VOf(Bf1));
    __hv_rpole_f(&sRPole_AtekGD6f, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_nANzx3UD, VIf(Bf8), &sEnv_nANzx3UD_sendMessage);
    __hv_varread_f(&sVarf_6gj6aMYw, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_gMikaZQe, VOf(Bf1));
    __hv_rpole_f(&sRPole_EIGKSCn1, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_zY6BSVsx, VIf(Bf1));
    __hv_line_f(&sLine_s8X0LSXF, VOf(Bf1));
    __hv_line_f(&sLine_AFnoiCaE, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_zf4W2DkK, VOf(Bf1));
    __hv_varread_f(&sVarf_bANcYv5C, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_y8Gq0zGl, VOf(Bf1));
    __hv_rpole_f(&sRPole_yFJPUwT4, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_rZJppz6b, VIf(Bf8), &sEnv_rZJppz6b_sendMessage);
    __hv_varread_f(&sVarf_bRmQVy3n, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ipL62r7u, VOf(Bf1));
    __hv_rpole_f(&sRPole_7nUqDMUz, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_pmp1WIHH, VIf(Bf1));
    __hv_varwrite_f(&sVarf_7DOxTcFR, VIf(Bf2));
    __hv_varread_f(&sVarf_VeOjnPMa, VOf(Bf2));
    __hv_varread_f(&sVarf_MOlUcSih, VOf(Bf1));
    __hv_line_f(&sLine_Of0RFGzc, VOf(Bf8));
    __hv_tabread_f(&sTabread_8SeePa5K, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_8YO848gA, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_ErK33IlO, VOf(Bf8));
    __hv_tabread_f(&sTabread_SLrxXmwY, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_VtbyeAnR, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_JXI3C9vk, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_4jc96OSn, VOf(Bf2));
    __hv_rpole_f(&sRPole_LfAur212, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_y3A77yE9, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_7yW6cXFh, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_bh0O2vyD, VIf(Bf2));
    __hv_varread_f(&sVarf_UndcrrtM, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_09e4BcNL, VOf(Bf1));
    __hv_rpole_f(&sRPole_Ou7FFuir, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_AfZUj88k, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_701SoLRi, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_9NIpHuaG, VIf(Bf1));
    __hv_varread_f(&sVarf_XnfwZdb2, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_WvPylBzD, VOf(Bf3));
    __hv_varread_f(&sVarf_GrNr1xC0, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_clWbRxZx, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_m3CG3nev, VOf(Bf3));
    __hv_varread_f(&sVarf_v4rq4hGI, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_tMaHM2sj, VOf(Bf3));
    __hv_rpole_f(&sRPole_fAFEWxuE, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_9eZh7Kzo, VIf(Bf9), &sEnv_9eZh7Kzo_sendMessage);
    __hv_varread_f(&sVarf_gPX0lrb6, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_r3VyMjQs, VOf(Bf3));
    __hv_rpole_f(&sRPole_56uQnv0G, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_JXI3C9vk, VIf(Bf3));
    __hv_line_f(&sLine_3QUy4KzU, VOf(Bf3));
    __hv_line_f(&sLine_Qmm3hGRE, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_OZ2fwsGT, VOf(Bf3));
    __hv_varread_f(&sVarf_orUszSzE, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_3mVDW4Oj, VOf(Bf3));
    __hv_rpole_f(&sRPole_fP1MeIRq, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_emHV5Ijb, VIf(Bf9), &sEnv_emHV5Ijb_sendMessage);
    __hv_varread_f(&sVarf_OBW5daYB, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_CumH3e2n, VOf(Bf3));
    __hv_rpole_f(&sRPole_GfmHoa6D, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_UndcrrtM, VIf(Bf3));
    __hv_varwrite_f(&sVarf_eWlSMkVc, VIf(Bf5));
    __hv_varread_f(&sVarf_PJdO7Fcc, VOf(Bf5));
    __hv_varread_f(&sVarf_e5NfP7N0, VOf(Bf3));
    __hv_line_f(&sLine_YmVBXEZM, VOf(Bf9));
    __hv_tabread_f(&sTabread_CtZzHWZD, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_5CHQrvtL, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_v6r3QXog, VOf(Bf9));
    __hv_tabread_f(&sTabread_SyMbVr0O, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_IFhTHKi1, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_rWWWKfqJ, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_vjLrYkOT, VOf(Bf5));
    __hv_rpole_f(&sRPole_1ZBhGghe, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_OZEYnsMi, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_iD2ndKwx, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_LBpS7k3D, VIf(Bf5));
    __hv_varread_f(&sVarf_ztQXTHOs, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_QVruoT5w, VOf(Bf3));
    __hv_rpole_f(&sRPole_2NL9iDAs, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_hZuhN6j4, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_RaJtEtDr, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_a02eutDN, VIf(Bf3));
    __hv_varread_f(&sVarf_Ltg8E5jn, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_cMGsPYMu, VOf(Bf2));
    __hv_varread_f(&sVarf_daQX3ia4, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_aB3XDVck, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_rtjfwUpU, VOf(Bf2));
    __hv_varread_f(&sVarf_svB0pd43, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_lzRsk3RJ, VOf(Bf2));
    __hv_rpole_f(&sRPole_2BgMJ0D4, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_bAbrHjx2, VIf(Bf8), &sEnv_bAbrHjx2_sendMessage);
    __hv_varread_f(&sVarf_LZsoioyI, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_GELHL6Aw, VOf(Bf2));
    __hv_rpole_f(&sRPole_EzTMnGgS, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_rWWWKfqJ, VIf(Bf2));
    __hv_line_f(&sLine_XBJlmObX, VOf(Bf2));
    __hv_line_f(&sLine_HvyAKPVz, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_HXJdsKi5, VOf(Bf2));
    __hv_varread_f(&sVarf_pZLZpwWB, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_b28JK72s, VOf(Bf2));
    __hv_rpole_f(&sRPole_A8HWPBCg, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_vZgAywzG, VIf(Bf8), &sEnv_vZgAywzG_sendMessage);
    __hv_varread_f(&sVarf_oLo0vntp, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_x336dEz1, VOf(Bf2));
    __hv_rpole_f(&sRPole_Uf9qDrRD, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_ztQXTHOs, VIf(Bf2));
    __hv_varwrite_f(&sVarf_FRM1AQT6, VIf(Bf1));
    __hv_varwrite_f(&sVarf_sLuTOy4F, VIf(Bf10));
    __hv_varwrite_f(&sVarf_my0sFozl, VIf(Bf11));
    __hv_varwrite_f(&sVarf_LpYcvzIO, VIf(Bf12));
    __hv_varwrite_f(&sVarf_VeOjnPMa, VIf(Bf0));
    __hv_varwrite_f(&sVarf_MOlUcSih, VIf(Bf6));
    __hv_varwrite_f(&sVarf_PJdO7Fcc, VIf(Bf4));
    __hv_varwrite_f(&sVarf_e5NfP7N0, VIf(Bf7));
    __hv_varread_f(&sVarf_sLuTOy4F, VOf(Bf7));
    __hv_varread_f(&sVarf_my0sFozl, VOf(Bf4));
    __hv_varread_f(&sVarf_LpYcvzIO, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_7DOxTcFR, VOf(Bf6));
    __hv_varread_f(&sVarf_eWlSMkVc, VOf(Bf7));
    __hv_varread_f(&sVarf_FRM1AQT6, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
